@@ -1,4 +1,4 @@
-//$Id: add-resource.h,v 1.2 2001/02/28 20:11:43 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.h,v 1.3 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_ADD_RESOURCE_H
-#define GUIKATCHU_ADD_RESOURCE_H
+#ifndef GUIKACHU_ADD_RESOURCE_H
+#define GUIKACHU_ADD_RESOURCE_H
 
 #include <glade/glade.h>
 #include <gtk--/entry.h>
@@ -48,4 +48,4 @@ namespace Guikachu
     }
 }
 
-#endif /* !GUIKATCHU_ADD_RESOURCE_H */
+#endif /* !GUIKACHU_ADD_RESOURCE_H */
