@@ -1,4 +1,4 @@
-//$Id: app-res.h,v 1.6 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: app-res.h,v 1.7 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,22 +50,22 @@ namespace Guikachu
 
 	    void show_ui ();
 
-	    Property<string> iconname;
-	    Property<string> version;
-	    Property<string> vendor;
+	    Property<std::string> iconname;
+	    Property<std::string> version;
+	    Property<std::string> vendor;
 	    
 	    void reset ();
 	    
 	private:
 	    bool load (StorageNode &node);
 	    void save (StorageNode &node) const;
-	    void save_rcp (ostream &ostr) const;
-	    friend ostream& operator<< (ostream &ostr, const Application *res);
+	    void save_rcp (std::ostream &ostr) const;
+	    friend std::ostream& operator<< (std::ostream &ostr, const Application *res);
 
 	    friend class ResourceManager;
 	};
 
-	ostream& operator<< (ostream &ostr, const Application* res);
+	std::ostream& operator<< (std::ostream &ostr, const Application* res);
     };
 };
 
