@@ -1,4 +1,4 @@
-//$Id: app-win.cc,v 1.7 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
+//$Id: app-win.cc,v 1.8 2001/11/06 17:04:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
@@ -39,7 +39,7 @@ GUI::AppWindow::AppWindow (Resources::Application *res_):
     window->set_policy (false, true, false);
     window->delete_event.connect (SigC::slot (this, &AppWindow::delete_event_impl));
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
     gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
 #endif    
 
