@@ -1,4 +1,4 @@
-//$Id: app-win.h,v 1.4 2001/05/02 14:01:34 cactus Exp $ -*- c++ -*-
+//$Id: app-win.h,v 1.5 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_APP_WIN_H
-#define GUIKATCHU_APP_WIN_H
+#ifndef GUIKACHU_APP_WIN_H
+#define GUIKACHU_APP_WIN_H
 
 namespace Guikachu
 {
@@ -52,4 +52,4 @@ namespace Guikachu
     };
 };
 
-#endif /* !GUIKATCHU_APP_WIN_H */
+#endif /* !GUIKACHU_APP_WIN_H */
