@@ -1,4 +1,4 @@
-//$Id: blob-res.cc,v 1.3 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: blob-res.cc,v 1.4 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,8 @@
 #include "blob-win.h"
 
 using namespace Guikachu;
+using std::string;
+using std::ostream;
 
 Resources::Blob::Blob (const string &id):
     Resource (id),
@@ -59,6 +61,6 @@ void Resources::Blob::save (StorageNode &node) const
 
 void Resources::Blob::save_rcp (ostream &ostr) const
 {
-    ostr << "/* Contents of blob '" << id << "' */" << endl;
-    ostr << contents << endl << endl;
+    ostr << "/* Contents of blob '" << id << "' */" << std::endl;
+    ostr << contents << std::endl << std::endl;
 }
