@@ -1,4 +1,4 @@
-//$Id: dialog-res.cc,v 1.15 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.cc,v 1.16 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,9 @@
 #include "dialog-win.h"
 
 using namespace Guikachu;
+using std::string;
+using std::vector;
+using std::ostream;
 
 Resources::Dialog::Dialog (const string& id):
     Resource (id),
@@ -164,31 +167,31 @@ void Resources::Dialog::save (StorageNode &node) const
 
 void Resources::Dialog::save_rcp (ostream &ostr) const
 {
-    ostr << "ALERT ID " << id << endl;
+    ostr << "ALERT ID " << id << std::endl;
     
     switch (dialog_type)
     {
     case DIALOG_INFORMATION:
-	ostr << "INFORMATION" << endl;
+	ostr << "INFORMATION" << std::endl;
 	break;
     case DIALOG_CONFIRMATION:
-	ostr << "CONFIRMATION" << endl;
+	ostr << "CONFIRMATION" << std::endl;
 	break;
     case DIALOG_WARNING:
-	ostr << "WARNING" << endl;
+	ostr << "WARNING" << std::endl;
 	break;
     case DIALOG_ERROR:
-	ostr << "ERROR" << endl;
+	ostr << "ERROR" << std::endl;
 	break;
     }
     
     if (help_id != "")
-	ostr << "  HELPID " << help_id << endl;
+	ostr << "  HELPID " << help_id << std::endl;
 
-    ostr << "BEGIN" << endl;
+    ostr << "BEGIN" << std::endl;
 
-    ostr << "  TITLE \"" << title << "\"" << endl
-	 << "  MESSAGE \"" << text << "\"" << endl;
+    ostr << "  TITLE \"" << title << "\"" << std::endl
+	 << "  MESSAGE \"" << text << "\"" << std::endl;
     if (buttons ().size ())
     {
 	ostr << "  BUTTONS ";
@@ -198,9 +201,9 @@ void Resources::Dialog::save_rcp (ostream &ostr) const
 	     i !=  buttons_vec.end (); i++)
 	    ostr << "\"" << *i << "\" ";
 	
-	ostr << endl;
+	ostr << std::endl;
     }
     
-    ostr << "END" << endl
-	 << endl;
+    ostr << "END" << std::endl
+	 << std::endl;
 }
