@@ -1,4 +1,4 @@
-//$Id: dialog-res.h,v 1.8 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.h,v 1.9 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -54,23 +54,23 @@ namespace Guikachu
 	{
 	    Guikachu::GUI::DialogWindow *gui;
 	public:
-	    Dialog (const string& id);
+	    Dialog (const std::string& id);
 	    virtual ~Dialog ();
 	    
 	    virtual Type get_type () const { return RESOURCE_DIALOG; };
 	    virtual void show_ui ();
 
-	    Property<string>          title;
-	    Property<string>          text;
-	    Property<DialogType>      dialog_type;
-	    Property<vector<string> > buttons;
-	    Property<unsigned int>    default_button;
-	    Properties::ResourceRef   help_id;
+	    Property<std::string>               title;
+	    Property<std::string>               text;
+	    Property<DialogType>                dialog_type;
+	    Property<std::vector<std::string> > buttons;
+	    Property<unsigned int>              default_button;
+	    Properties::ResourceRef             help_id;
 	    
 	private:
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     };
 };
