@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.19 2001/11/03 20:18:26 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.20 2001/11/06 17:04:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
@@ -164,7 +164,7 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     window.delete_event.connect (slot (this, &DialogWindow::delete_event_impl));
     window.set_policy (false, true, false);
     
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
     gnome_window_icon_set_from_file (window.gtkobj (), GNOME_ICONDIR "/guikachu.png");
 #endif
 
