@@ -1,4 +1,4 @@
-//$Id: dialog-win.h,v 1.10 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.h,v 1.11 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,9 +43,6 @@ namespace Guikachu
 	    Gtk::Window          window;
 	    
 	    Gtk::OptionMenu      type_combo;
-	    
-//	    Gtk::List           *button_list;
-//	    Gtk::Button         *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
 	public:
 	    DialogWindow (Resources::Dialog *res_);
 	    void show ();
@@ -55,17 +52,6 @@ namespace Guikachu
 
 	    void type_menu_cb (Resources::DialogType type);
 	    bool update_block;
-
-#if 0
-	    void button_add_cb ();
-	    void button_remove_cb ();
-	    void button_default_cb ();
-	    void button_up_cb ();
-	    void button_down_cb ();
-	    void button_sel_change_cb ();
-	    
-	    void dialog_add_cb (string name);
-#endif
 	};
     };
 };
