@@ -1,4 +1,4 @@
-//$Id: button-canvas.h,v 1.3 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.h,v 1.5 2001/10/31 20:01:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,11 +32,17 @@ namespace Guikachu
 	    {
 		Widgets::Button    *widget;
 		Gnome::CanvasGroup *group;
+
 	    public:
 		ButtonCanvasItem (Widgets::Button  *widget,
 				  FormEditor::Form *form);
+
 	    protected:
 		virtual void update ();
+
+	    private:
+		void create_simple_border ();
+		void create_bold_border ();
 	    };
 	}
     }
