@@ -1,4 +1,4 @@
-//$Id: button-prop.cc,v 1.15 2001/10/18 19:14:08 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.cc,v 1.16 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -98,8 +98,7 @@ ButtonProperties::ButtonProperties (Button *res_):
     ResizeableProperties::add_controls (res, *proptable);
     
     proptable->show ();
-    property_editor = manage (proptable);
-    gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+    property_editor = proptable;
 
     res->changed.connect (slot (this, &ButtonProperties::update));
     update ();
