@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.26 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.27 2001/11/15 20:21:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -222,13 +222,13 @@ void Button::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int Button::get_auto_width ()
+int Button::get_auto_width () const
 {
     int text_width = get_string_width (font, text);
     return 6 + text_width + 6;
 }
 
-int Button::get_auto_height ()
+int Button::get_auto_height () const
 {
     int text_height = get_font_height (font);
 
