@@ -1,4 +1,4 @@
-//$Id: button.h,v 1.13 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: button.h,v 1.14 2001/11/15 20:21:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -67,8 +67,8 @@ namespace Guikachu
 	    Property<bool>            anchor_right;
 
 	protected:
-	    virtual int get_auto_width ();
-	    virtual int get_auto_height ();
+	    virtual int get_auto_width  () const ;
+	    virtual int get_auto_height () const;
 	    
 	private:
 	    // Persistance
