@@ -1,4 +1,4 @@
-//$Id: canvasitem.cc,v 1.16 2001/10/27 13:29:26 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.17 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,7 +44,7 @@ CanvasItem::CanvasItem (Widgets::Widget  *widget_,
     drag_context.drag_occured = false;
     
     // Popup menu
-    list <Gnome::UI::Info> popup_menu_list;
+    std::list <Gnome::UI::Info> popup_menu_list;
     popup_menu_list.push_back (
 	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
 			 _("Remove"), menu_remove.slot ()));
@@ -161,7 +161,7 @@ void CanvasItem::drag_motion_impl (GdkEvent *e)
     drag_context.last_x = curr_x;
     drag_context.last_y = curr_y;     
 
-    drag_motion.emit (dx / 1, dy / 1);
+    drag_motion.emit (int (dx), int (dy));
 }
 
 void CanvasItem::drag_end_impl (GdkEvent *e)
