@@ -1,4 +1,4 @@
-//$Id: canvasitem.h,v 1.5 2001/09/19 20:30:53 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.h,v 1.9 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,18 +47,22 @@ namespace Guikachu
 		Gnome::CanvasGroup *item;
 		Widgets::Widget    *widget;
 		Gnome::CanvasItem  *bounding_box;
+
+		Gtk::Menu           popup_menu;
 		
 		struct
 		{
 		    bool dragging;
 		    bool drag_occured;
 
+		    double start_x, start_y;
 		    double last_x, last_y;
 		    double offset_x, offset_y;
+		    double delta_remainder_x, delta_remainder_y;
 		} drag_context;
+		
 	    protected:
 		FormEditor::Form  *form;
-		Gtk::Menu          popup_menu;
 		bool selected;
 		
 	    protected:
@@ -69,21 +73,31 @@ namespace Guikachu
 		
 	    public:
 		virtual ~CanvasItem ();
+		
 		SigC::Signal0<void> clicked;
 
+		SigC::Signal0<void> menu_remove;
+		
+		SigC::Signal0<void>           drag_begin;
+		SigC::Signal2<void, int, int> drag_motion; // arguments are dx and dy
+		SigC::Signal2<void, int, int> drag_end;    // arguments are dx and dy
+		SigC::Signal0<void>           drag_cancel;
+
+		void move (int dx, int dy);
+		
 	    private:
 		void widget_selected_cb (bool      selected);
 		int  canvas_event_cb    (GdkEvent *event);
 
-		void remove_cb ();
-		void move_cb ();
-
-		void drag_begin  (GdkEvent *event);
-		void drag_motion (GdkEvent *event);
-		void drag_end    (GdkEvent *event);
+		void drag_begin_impl  (GdkEvent *event);
+		void drag_motion_impl (GdkEvent *event);
+		void drag_end_impl    (GdkEvent *event);
 
+	    protected:
 		virtual void update () = 0;
 		virtual Gnome::CanvasItem * create_bounding_box ();
+		virtual void get_bounds (int &x1, int &y1,
+					 int &x2, int &y2);
 	    };
 	}
     }
