@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.cc,v 1.14 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.cc,v 1.15 2001/11/25 19:50:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -99,8 +99,8 @@ void CheckboxCanvasItem::get_bounds (int &x1, int &y1,
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
 
-    width = MAX (18, width);
-    height = MAX (10, height);
+    width  = std::max (18, width);
+    height = std::max (10, height);
     
     x1 = widget->x - 1;
     x2 = x1 + width + 1 + 1;
