@@ -1,4 +1,4 @@
-//$Id: checkbox.cc,v 1.14 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.cc,v 1.15 2001/11/15 20:21:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -261,12 +261,12 @@ void Checkbox::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int Checkbox::get_auto_width ()
+int Checkbox::get_auto_width () const
 {
     return 18 + get_string_width (font, text);
 }
 
-int Checkbox::get_auto_height ()
+int Checkbox::get_auto_height () const
 {
     return 3 + get_font_height (font);
 }
