@@ -1,4 +1,4 @@
-//$Id: checkbox.h,v 1.11 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.h,v 1.12 2001/11/15 20:21:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -77,8 +77,8 @@ namespace Guikachu
 	    ToggledProp    toggled;
 
 	protected:
-	    virtual int get_auto_width ();
-	    virtual int get_auto_height ();
+	    virtual int get_auto_width  () const;
+	    virtual int get_auto_height () const;
 	    
 	private:
 	    // Persistance
