@@ -1,4 +1,4 @@
-//$Id: font.cc,v 1.5 2001/10/25 21:30:32 cactus Exp $ -*- c++ -*-
+//$Id: font.cc,v 1.7 2001/11/06 17:04:31 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,7 +25,7 @@
 
 using namespace Guikachu::GUI::FormEditor;
 
-Font::Font (const string &filename):
+Font::Font (const std::string &filename):
     height (0)
 {
     parse (filename);
@@ -36,19 +36,19 @@ Font::Font ():
 {
 }
 
-void Font::parse (const string &filename)
+void Font::parse (const std::string &filename)
 {
-    ifstream stream ((string (FONTDIR) + "/" + filename).c_str ());
+    std::ifstream stream ((std::string (FONTDIR) + "/" + filename).c_str ());
 
     parse (stream);
 }
 
-void Font::parse (istream &stream)
+void Font::parse (std::istream &stream)
 {
     /* FIXME: Error handling, robustness issues regarding garbage
      * input */
     
-    string curr_line;
+    std::string curr_line;
     bool in_header = true;
     
     while (in_header)
@@ -58,9 +58,9 @@ void Font::parse (istream &stream)
 	if (curr_line == "")
 	    continue;
 	
-	strstream curr_line_stream;
-	string    param_name;
-	int       param_val;
+	std::strstream curr_line_stream;
+	std::string    param_name;
+	int            param_val;
 	
 	curr_line_stream << curr_line;
 	curr_line_stream >> param_name;
@@ -81,16 +81,16 @@ void Font::parse (istream &stream)
 
     while (!stream.eof ())
     {
-	strstream curr_line_stream;
-	string    param_name;
+	std::strstream curr_line_stream;
+	std::string    param_name;
 	
 	curr_line_stream << curr_line;
 	curr_line_stream >> param_name;
 
 	if (param_name == "GLYPH")
 	{
-	    string glyph_index;
-	    char   glyph_char;
+	    std::string glyph_index;
+	    char        glyph_char;
 	    
 	    curr_line_stream >> glyph_index;
 
@@ -105,7 +105,7 @@ void Font::parse (istream &stream)
 	    /* Parse current glyph */
 	    Glyph curr_glyph (stream, height);
 
-	    glyphs.insert (pair <char, Glyph> (glyph_char, curr_glyph));
+	    glyphs.insert (std::pair <char, Glyph> (glyph_char, curr_glyph));
 	}
 	
 	getline (stream, curr_line);
@@ -118,18 +118,18 @@ static void free_pixdata_delete (guchar *pixels, gpointer data)
 }
 
 
-GdkPixbuf* Font::render (const string    &text,
-			 const Gdk_Color &color) const
+GdkPixbuf* Font::render (const std::string &text,
+			 const Gdk_Color   &color) const
 {
     if (text == "")
 	return 0;
     
-    list <Glyph> typeset;
+    std::list <Glyph> typeset;
     int width = 0;
     
     for (unsigned int i = 0; i < text.length (); i++)
     {
-	hash_map<char, Glyph>::const_iterator curr_glyph_i = glyphs.find (text[i]);
+	std::hash_map<char, Glyph>::const_iterator curr_glyph_i = glyphs.find (text[i]);
 	
 	if (curr_glyph_i != glyphs.end ())
         {
@@ -143,7 +143,7 @@ GdkPixbuf* Font::render (const string    &text,
     guchar *pixbuf_data = new guchar[width * height * 4];
     int x_position = 0;
 
-    for (list<Glyph>::const_iterator i = typeset.begin ();
+    for (std::list<Glyph>::const_iterator i = typeset.begin ();
          i != typeset.end (); i++)
     {
         const Glyph& glyph = *i;
@@ -180,7 +180,7 @@ GdkPixbuf* Font::render (const string    &text,
 				     free_pixdata_delete, 0);
 }
 
-unsigned int Font::string_width (const string &text) const
+unsigned int Font::string_width (const std::string &text) const
 {
     if (text == "")
 	return 0;
@@ -189,7 +189,7 @@ unsigned int Font::string_width (const string &text) const
     
     for (unsigned int i = 0; i < text.length (); i++)
     {
-	hash_map<char, Glyph>::const_iterator curr_glyph_i = glyphs.find (text[i]);
+	std::hash_map<char, Glyph>::const_iterator curr_glyph_i = glyphs.find (text[i]);
 	
 	if (curr_glyph_i != glyphs.end ())
 	    width += curr_glyph_i->second.width;
