@@ -1,4 +1,4 @@
-//$Id: font.h,v 1.3 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
+//$Id: font.h,v 1.5 2001/11/06 17:04:31 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 
 #include <string>
 #include <iostream>
-#include <hash_map>
+#include "hash-map.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk--/color.h>
@@ -38,24 +38,25 @@ namespace Guikachu
 		int            offset;
 		bool         **bitmap;
 	    public:
-		Glyph (istream &stream, unsigned int &height);
+		Glyph (std::istream &stream, unsigned int &height);
 	    };
 	    
 	    class Font
 	    {
-		hash_map <char, Glyph> glyphs;
-		unsigned int           height, ascent, descent;
+		std::hash_map <char, Glyph> glyphs;
+		unsigned int                height, ascent, descent;
 		
 	    public:
-		Font (const string &filename);
+		Font (const std::string &filename);
 		Font ();
 
-		void parse (const string &filename);
-		void parse (istream      &stream);
+		void parse (const std::string &filename);
+		void parse (std::istream      &stream);
 
-		GdkPixbuf* render (const string    &text,
-				   const Gdk_Color &color) const;
-		unsigned int string_width (const string& text) const;
+		GdkPixbuf* render (const std::string &text,
+				   const Gdk_Color   &color) const;
+
+		unsigned int string_width (const std::string& text) const;
 		
 		int get_height  () const { return height; };
 		int get_ascent  () const { return ascent; };
