@@ -1,4 +1,4 @@
-//$Id: form-editor.h,v 1.14 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
+//$Id: form-editor.h,v 1.15 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,24 +42,28 @@ namespace Guikachu
 	    const Font &get_font (int font_num);
 	    const Font &get_title_font ();
 	    
-	    unsigned int get_font_height (int font_num);
-	    unsigned int get_string_width (int font_num, const string& text);
+	    unsigned int get_font_height  (int font_num);
+	    unsigned int get_string_width (int font_num, const std::string& text);
 	    
-	    Gnome::CanvasItem* draw_text (Gnome::CanvasGroup &group,
-					  const string &text,
-					  int font_num,
-					  int x, int y,
-					  bool usable = true,
-					  GtkAnchorType anchor = GTK_ANCHOR_NW,
-					  int clip_width = 0, int clip_height = 0);
+	    Gnome::CanvasItem* draw_text   (Gnome::CanvasGroup &group,
+					    const std::string  &text,
+					    int                 font_num,
+					    int                 x,
+					    int                 y,
+					    bool                usable,
+					    GtkAnchorType       anchor = GTK_ANCHOR_NW,
+					    int                 clip_width = 0,
+					    int                 clip_height = 0);
 
 	    Gnome::CanvasItem* render_text (Gnome::CanvasGroup &group,
-					    const string    &text,
-					    const Font      &font,
-					    const Gdk_Color &color,
-					    int x, int y,
-					    GtkAnchorType anchor = GTK_ANCHOR_NW,
-					    int clip_width = 0, int clip_height = 0);
+					    const std::string  &text,
+					    const Font         &font,
+					    const Gdk_Color    &color,
+					    int                 x,
+					    int                 y,
+					    GtkAnchorType       anchor = GTK_ANCHOR_NW,
+					    int                 clip_width = 0,
+					    int                 clip_height = 0);
 
 	    // Use this instead of Rectangle canvas items because
 	    // those are shoddy
