@@ -1,4 +1,4 @@
-//$Id: form-prop.cc,v 1.12 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: form-prop.cc,v 1.13 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -99,8 +99,7 @@ FormProperties::FormProperties (Resources::Form *res_):
 		    _("Vertical size of the form"));
     
     proptable->show ();
-    property_editor = manage (proptable);
-    gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+    property_editor = proptable;
 }
 
 FormProperties::~FormProperties ()
