@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.28 2001/11/15 23:18:33 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.29 2001/11/25 19:50:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -202,14 +202,14 @@ void Form::draw_title ()
 void Form::draw_title_nonmodal ()
 {
     Gnome::CanvasPoints points;
-    double title_width;
+    int title_width;
     const Font &font = get_title_font ();
 
     title_width = get_string_width (1, res->title); /* Title is font#1 (FIXME) */
-    title_width = MIN (title_width + 4, res->width);
+    title_width = std::min<int> (title_width + 4, res->width);
 
     int max_width = res->width;
-    int max_height = MIN (res->height, GUIKACHU_WINDOW_TITLE_HEIGHT);
+    int max_height = std::min<int> (res->height, GUIKACHU_WINDOW_TITLE_HEIGHT);
     
     // NW corner
     points.push_back (Gnome::Art::Point (0, 1));
@@ -253,10 +253,10 @@ void Form::draw_title_modal ()
     const Font &font = get_title_font ();
 
     int title_center = res->width / 2;
-    int title_height = MIN (res->height, 11);
+    int title_height = std::min<int> (res->height, 11);
 
     int max_width = res->width;
-    int max_height = MIN (res->height, 11);
+    int max_height = std::min<int> (res->height, 11);
 
     {
 	using namespace Gnome::CanvasHelpers;
