@@ -1,4 +1,4 @@
-//$Id: gadget-canvas.cc,v 1.1 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
+//$Id: gadget-canvas.cc,v 1.2 2001/10/26 13:07:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -56,7 +56,7 @@ void GadgetCanvasItem::update ()
      * inside the "hollow" area
      */
     Gnome::CanvasPoints frame_points;
-    using namespace Gnome::Art;
+    using Gnome::Art::Point;
     
     frame_points.push_back (Point (x1, y1));
     frame_points.push_back (Point (x2, y1));
