@@ -1,4 +1,4 @@
-//$Id: gadget-prop.cc,v 1.2 2001/10/22 17:38:11 cactus Exp $ -*- c++ -*-
+//$Id: gadget-prop.cc,v 1.3 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -62,8 +62,7 @@ GadgetProperties::GadgetProperties (Gadget *res)
     proptable->add (_("_Height:"), *manage (control),
 		    _("Vertical size of the widget"));
     
-    property_editor = manage (proptable);
-    gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+    property_editor = proptable;
 }
 
 GadgetProperties::~GadgetProperties ()
