@@ -1,4 +1,4 @@
-//$Id: gadget.h,v 1.1 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
+//$Id: gadget.h,v 1.2 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,8 +40,8 @@ namespace Guikachu
 	    GUI::FormEditor::GadgetProperties *editor;
 	    
 	public:
-	    Gadget (Resources::Form *owner,
-		    const string& id);
+	    Gadget (Resources::Form   *owner,
+		    const std::string &id);
 	    virtual ~Gadget ();
 	    
 	    virtual Type get_type () const { return WIDGET_GADGET; };
@@ -57,7 +57,7 @@ namespace Guikachu
 	    // Persistance
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     }
 }
