@@ -1,4 +1,4 @@
-//$Id: glyph.cc,v 1.1 2001/07/05 18:07:05 cactus Exp $ -*- c++ -*-
+//$Id: glyph.cc,v 1.2 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,16 +25,16 @@ using namespace Guikachu::GUI::FormEditor;
 #define GLYPH_ON  '#'
 #define GLYPH_OFF '-'
 
-Glyph::Glyph (istream      &stream,
+Glyph::Glyph (std::istream &stream,
 	      unsigned int &height):
     width (0),
     offset (0),
     bitmap (0)
 {
     
-    string curr_line;
-    bool in_bitmap = true;
-    bool in_header = true;
+    std::string curr_line;
+    bool        in_bitmap = true;
+    bool        in_header = true;
 
     while (in_header)
     {
@@ -47,9 +47,9 @@ Glyph::Glyph (istream      &stream,
 	    continue;
 	}
 
-	strstream curr_line_stream;
-	string    param_name;
-	int       param_val;
+	std::strstream curr_line_stream;
+	std::string    param_name;
+	int            param_val;
 	
 	curr_line_stream << curr_line;
 	curr_line_stream >> param_name;
