@@ -1,4 +1,4 @@
-//$Id: graffiti-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.h,v 1.4 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKACHU_FORM_EDITOR_GRAFITI_CANVAS_H
-#define GUIKACHU_FORM_EDITOR_GRAFITI_CANVAS_H
+#ifndef GUIKACHU_FORM_EDITOR_GRAFFITI_CANVAS_H
+#define GUIKACHU_FORM_EDITOR_GRAFFITI_CANVAS_H
 
 #include "graffiti.h"
 
@@ -36,11 +36,11 @@ namespace Guikachu
 	    public:
 		GraffitiCanvasItem (Widgets::Graffiti *res,
 				    FormEditor::Form  *form);
-	    private:
+	    protected:
 		virtual void update ();
 	    };
 	}
     }
 }
 
-#endif /* !GUIKACHU_FORM_EDITOR_GRAFITI_CANVAS_H */
+#endif /* !GUIKACHU_FORM_EDITOR_GRAFFITI_CANVAS_H */
