@@ -1,4 +1,4 @@
-//$Id: graffiti-prop.h,v 1.2 2001/04/25 16:05:25 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-prop.h,v 1.3 2001/08/19 15:02:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,6 @@
 
 #include <string>
 #include <iostream>
-#include <sigc++/object.h>
 
 namespace Guikachu
 {
@@ -42,7 +41,7 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class GraffitiProperties: public SigC::Object
+	    class GraffitiProperties
 	    {
 		Gtk::Widget *property_editor;
 		
