@@ -1,4 +1,4 @@
-//$Id: graffiti.cc,v 1.9 2001/10/19 11:47:44 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.cc,v 1.10 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,8 +24,8 @@
 using Guikachu::Widgets::Graffiti;
 using namespace Guikachu::GUI::FormEditor;
 
-Graffiti::Graffiti (Resources::Form *owner,
-		    const string& id):
+Graffiti::Graffiti (Resources::Form   *owner,
+		    const std::string &id):
     Widget (owner, id),
     editor (0)
 {
@@ -81,10 +81,10 @@ void Graffiti::save (StorageNode &node) const
     my_node.set_prop ("y", y);
 }
 
-void Graffiti::save_rcp (ostream &ostr) const
+void Graffiti::save_rcp (std::ostream &ostr) const
 {
     ostr << "  GRAFFITISTATEINDICATOR";
     ostr << " AT (" << x << " " << y << ")";
-    ostr << endl;
+    ostr << std::endl;
 }
 
