@@ -1,4 +1,4 @@
-//$Id: label-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
+//$Id: label-canvas.h,v 1.3 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,7 +39,7 @@ namespace Guikachu
 	    public:
 		LabelCanvasItem (Widgets::Label   *widget,
 				 FormEditor::Form *form);
-	    private:
+	    protected:
 		virtual void update ();
 	    };
 	}
