@@ -1,4 +1,4 @@
-//$Id: label.cc,v 1.23 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
+//$Id: label.cc,v 1.24 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,13 +19,11 @@
 #include "label.h"
 #include "label-canvas.h"
 
-#include <gnome-xml/xmlmemory.h>
-
 using Guikachu::Widgets::Label;
 using namespace Guikachu::GUI::FormEditor;
 
-Label::Label (Resources::Form *owner,
-	      const string& id):
+Label::Label (Resources::Form   *owner,
+	      const std::string &id):
     Widget (owner, id),
     Textual (changed, id),
     editor (0),
@@ -101,7 +99,7 @@ void Label::save (StorageNode &node) const
     my_node.set_prop ("font", font);
 }
 
-void Label::save_rcp (ostream &ostr) const
+void Label::save_rcp (std::ostream &ostr) const
 {
     ostr << "  LABEL \"" << text << "\"" << " ID " << id;
     ostr << " AT (" << x << " " << y << ")";
@@ -110,5 +108,5 @@ void Label::save_rcp (ostream &ostr) const
 	ostr << " USABLE";
     else
 	ostr << " NONUSABLE";
-    ostr << endl;
+    ostr << std::endl;
 }
