@@ -1,4 +1,4 @@
-//$Id: label.h,v 1.13 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: label.h,v 1.14 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,8 +43,8 @@ namespace Guikachu
 	    GUI::FormEditor::LabelProperties *editor;
 	    
 	public:
-	    Label (Resources::Form *owner,
-		   const string& id);
+	    Label (Resources::Form   *owner,
+		   const std::string &id);
 	    virtual ~Label ();
 	    
 	    virtual Type get_type () const { return WIDGET_LABEL; };
@@ -52,13 +52,13 @@ namespace Guikachu
 	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget                 *create_editor ();
 	    
-	    Property<bool>   usable;
+	    Property<bool> usable;
 	    
 	private:
 	    // Persistance
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     }
 }
