@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.14 2001/11/11 20:56:01 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.15 2001/11/25 19:50:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,8 +50,7 @@ void ListCanvasItem::update ()
     const std::vector<std::string> &listitems = widget->items;
 
     // FIXME: size() is unsigned, visible_items is signed
-    int num_items = listitems.size ();
-    int visible_strings = MIN (widget->visible_items, num_items);
+    int visible_strings = std::min<int> (widget->visible_items, listitems.size ());
     
     int line_spacing = get_font_height (font_num);
     int text_y = widget->y;
