@@ -1,4 +1,4 @@
-//$Id: list.cc,v 1.14 2001/11/11 20:56:01 cactus Exp $ -*- c++ -*-
+//$Id: list.cc,v 1.15 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -175,7 +175,7 @@ void List::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int List::get_display_width ()
+int List::get_display_width () const
 {
     if (manual_width && width != 0)
 	return width;
@@ -183,7 +183,7 @@ int List::get_display_width ()
 	return get_auto_width ();
 }
 
-int List::get_auto_width ()
+int List::get_auto_width () const
 {
     int width = 18;
     if (items ().size ())
