@@ -1,4 +1,4 @@
-//$Id: list.h,v 1.9 2001/11/11 20:56:01 cactus Exp $ -*- c++ -*-
+//$Id: list.h,v 1.10 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -60,8 +60,9 @@ namespace Guikachu
 	    Property<int>                       width;
 	    Property<bool>                      manual_width;
 
-	    int get_display_width ();
-	    int get_auto_width ();
+	    int get_display_width () const;
+	protected:
+	    int get_auto_width () const;
 
 	private:
 	    void manual_width_cb ();
