@@ -1,4 +1,4 @@
-//$Id: palette.h,v 1.5 2001/10/16 16:11:49 cactus Exp $ -*- c++ -*-
+//$Id: palette.h,v 1.6 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,10 +42,10 @@ namespace Guikachu
     {
 	class Palette: public Gtk::Window
 	{
-	    Gtk::Tooltips            tips;
-	    Gtk::Label               current_widget_name;
-	    list<Gtk::ToggleButton*> buttons;
-	    bool                     sticky;
+	    Gtk::Tooltips                 tips;
+	    Gtk::Label                    current_widget_name;
+	    std::list<Gtk::ToggleButton*> buttons;
+	    bool                          sticky;
 	public:
 	    Palette ();
 
@@ -54,7 +54,7 @@ namespace Guikachu
 	    
 	private:
 	    Gtk::ToggleButton* create_button (Widgets::Type       type,
-					      const string       &tooltip,
+					      const std::string  &tooltip,
 					      const char * const *icon_xpm);
 
 	    int  delete_event_impl (GdkEventAny *e);
