@@ -1,4 +1,4 @@
-//$Id: popup-trigger-canvas.cc,v 1.7 2001/10/20 16:06:51 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-canvas.cc,v 1.9 2001/11/01 13:19:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -71,7 +71,7 @@ void PopupTriggerCanvasItem::update ()
 	       text_x, text_y,
 	       widget->usable,
 	       GTK_ANCHOR_NW,
-	       width, height);
+	       width - 15, height);
 
     set_canvas_item (group);
 }
@@ -80,7 +80,7 @@ void PopupTriggerCanvasItem::get_bounds (int &x1, int &y1,
 					 int &x2, int &y2)
 {
     x1 = widget->x;
-    x2 = x1 + widget->get_display_width () + 15 + 2;
+    x2 = x1 + widget->get_display_width () + 2;
     y1 = widget->y - 1;
     y2 = y1 + widget->get_display_height () +2;
 }
