@@ -1,4 +1,4 @@
-//$Id: popup-trigger-canvas.h,v 1.1 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-canvas.h,v 1.2 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,8 +36,10 @@ namespace Guikachu
 	    public:
 		PopupTriggerCanvasItem (Widgets::PopupTrigger *widget,
 					FormEditor::Form      *form);
-	    private:
+	    protected:
 		virtual void update ();
+		virtual void get_bounds (int &x1, int &y1,
+					 int &x2, int &y2);
 	    };
 	}
     }
