@@ -1,4 +1,4 @@
-//$Id: popup-trigger-prop.h,v 1.1 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-prop.h,v 1.3 2001/08/19 15:02:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,10 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_PROP_H
 #define GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_PROP_H
 
-#include <string>
-#include <iostream>
-#include <sigc++/object.h>
-
 namespace Guikachu
 {
     namespace GUI
@@ -42,7 +38,7 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class PopupTriggerProperties: public SigC::Object
+	    class PopupTriggerProperties
 	    {
 		Gtk::Widget *property_editor;
 	    public:
