@@ -1,4 +1,4 @@
-//$Id: pushbutton-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-canvas.h,v 1.4 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,8 +36,10 @@ namespace Guikachu
 	    public:
 		PushButtonCanvasItem (Widgets::PushButton *widget,
 				      FormEditor::Form    *form);
-	    private:
+	    protected:
 		virtual void update ();
+		virtual void get_bounds (int &x1, int &y1,
+					 int &x2, int &y2);
 	    };
 	}
     }
