@@ -1,4 +1,4 @@
-//$Id: pushbutton.cc,v 1.14 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.cc,v 1.15 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -169,14 +169,14 @@ void PushButton::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int PushButton::get_auto_width ()
+int PushButton::get_auto_width () const
 {
     int text_width = get_string_width (font, text);
 
     return text_width + 6;
 }
 
-int PushButton::get_auto_height ()
+int PushButton::get_auto_height () const
 {
     return get_font_height (font);
 }
