@@ -1,4 +1,4 @@
-//$Id: pushbutton.h,v 1.10 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.h,v 1.11 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -57,8 +57,8 @@ namespace Guikachu
 	    Property<int>    group;
 
 	protected:
-	    virtual int get_auto_width  ();
-	    virtual int get_auto_height ();
+	    virtual int get_auto_width  () const;
+	    virtual int get_auto_height () const;
 
 	private:
 	    // Persistance
