@@ -1,4 +1,4 @@
-//$Id: scrollbar-canvas.cc,v 1.10 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-canvas.cc,v 1.11 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,7 +50,7 @@ void ScrollBarCanvasItem::update ()
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
 
     int width = widget->get_display_width ();
-    int height = widget->get_display_height ();
+    int height = widget->height;
 
     int x1 = widget->x;
     int y1 = widget->y;
