@@ -1,4 +1,4 @@
-//$Id: scrollbar-prop.h,v 1.2 2001/09/07 21:03:08 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-prop.h,v 1.3 2001/09/27 22:23:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,14 +39,17 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class ScrollBarProperties
+	    class ScrollBarProperties: public SigC::Object
 	    {
-		Gtk::Widget   *property_editor;
-		GUI::NumEntry *value, *min_value, *max_value;
+		Widgets::ScrollBar *res;
+		Gtk::Widget        *property_editor;
+		GUI::NumEntry      *value, *min_value, *max_value;
 	    public:
 		ScrollBarProperties (Widgets::ScrollBar *res);
 		~ScrollBarProperties ();
 		Gtk::Widget *get_editor ();
+	    private:
+		void update ();
 	    };
 	}
     }
