@@ -1,4 +1,4 @@
-//$Id: scrollbar.cc,v 1.12 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.13 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,15 +29,18 @@ using namespace Guikachu::GUI::FormEditor;
 ScrollBar::ScrollBar (Resources::Form   *owner,
 		      const std::string &id):
     Widget (owner, id),
-    Resizeable (changed),
     editor (0),
     usable (changed, true),
     min_value (changed, 0),
     max_value (changed, 0),
     value (changed, 0),
-    page_size (changed, 0)
+    page_size (changed, 0),
+    width (changed, 0),
+    manual_width (manual_width_changed, false),
+    height (changed, 40)
 {
     changed.connect (SigC::slot (this, &ScrollBar::update));
+    manual_width_changed.connect (SigC::slot (this, &ScrollBar::manual_width_cb));
 }
 
 ScrollBar::~ScrollBar ()
@@ -102,16 +105,13 @@ bool ScrollBar::load (StorageNode &node)
 		manual_width = true;
 		width = atoi (width_str.c_str ());
 	    }
-	    
+
+	    /* Compatibility for pre-1.0 Guikachu files */
 	    std::string height_str = curr_node.get_prop<std::string> ("height");
 	    if (height_str == "auto")
-	    {
-		manual_height = false;
-		height = 0;
-	    } else {
-		manual_height = true;
+		height = 100;
+	    else
 		height = atoi (height_str.c_str ());
-	    }
 	}
 	else if (curr_node.name () == "usable")
 	    usable = true;
@@ -148,10 +148,7 @@ void ScrollBar::save (StorageNode &node) const
     else
 	my_node.set_prop ("width", "auto");
 
-    if (manual_height)
-	my_node.set_prop ("height", height);
-    else
-	my_node.set_prop ("height", "auto");
+    my_node.set_prop ("height", height);
     
     /* Usable */
     if (usable)
@@ -169,15 +166,8 @@ void ScrollBar::save_rcp (std::ostream &ostr) const
 {
     gchar *width_str, *height_str;
 
-    if (manual_width)
-	width_str = g_strdup_printf ("%d", width ());
-    else
-	width_str = g_strdup ("7");
-    
-    if (manual_height)
-	height_str = g_strdup_printf ("%d", height ());
-    else
-	height_str = g_strdup ("AUTO");
+    width_str = g_strdup_printf ("%d", get_display_width ());
+    height_str = g_strdup_printf ("%d", height ());
 
     ostr << "  SCROLLBAR ID " << id;
     ostr << " AT (" << x << " " << y << " " << width_str << " " << height_str << ")";
@@ -192,12 +182,23 @@ void ScrollBar::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int ScrollBar::get_auto_width ()
+int ScrollBar::get_display_width () const
+{
+    if (manual_width && width != 0)
+	return width;
+    else
+	return get_auto_width ();
+}
+
+int ScrollBar::get_auto_width () const
 {
     return 7; /* recommended width for scroll bars */
 }
 
-int ScrollBar::get_auto_height ()
+void ScrollBar::manual_width_cb ()
 {
-    return 100;
+    if (width == 0)
+	width = get_auto_width ();
+    else
+	changed.emit ();
 }
