@@ -1,4 +1,4 @@
-//$Id: scrollbar.h,v 1.8 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.9 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,10 +36,11 @@ namespace Guikachu
 {
     namespace Widgets
     {
-	class ScrollBar: public Widget,
-			 public Resizeable
+	class ScrollBar: public Widget
 	{
 	    GUI::FormEditor::ScrollBarProperties *editor;
+
+	    SigC::Signal0<void> manual_width_changed;
 	    
 	public:
 	    ScrollBar (Resources::Form   *owner,
@@ -54,9 +55,17 @@ namespace Guikachu
 	    Property<bool> usable;
 	    Property<int>  min_value, max_value, value, page_size;
 
+	    Property<int>  width;
+	    Property<bool> manual_width;
+	    Property<int>  height;
+	    
+	    int get_display_width () const;
+
 	protected:
-	    virtual int get_auto_width  ();
-	    virtual int get_auto_height ();
+	    int get_auto_width () const;
+
+	private:
+	    void manual_width_cb ();
 	    
 	private:
 	    // Persistance
