@@ -1,4 +1,4 @@
-//$Id: selector-trigger-canvas.cc,v 1.13 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.15 2001/11/01 13:20:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,7 +20,7 @@
 
 #include "form-editor.h"
 
-#include <gnome--/canvas-polygon.h>
+#include <gnome--/canvas-property.h>
 
 using namespace Guikachu::GUI::FormEditor;
 
@@ -43,41 +43,32 @@ void SelectorTriggerCanvasItem::update ()
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
 
-    /* Don't ask about the +1, I have no idea... */
+    /* Don't ask about the -1, I have no idea... */
     int x1 = widget->x;
-    int x2 = x1 + width + 1;
+    int x2 = x1 + width;
     int y1 = widget->y;
-    int y2 = y1 + height + 1;
+    int y2 = y1 + height;
 
     /* A Polygon is used instead of a Rectangle to get mouse events
      * inside the "hollow" area
      */
-    Gnome::CanvasPoints frame_points;
-    using namespace Gnome::Art;
-    
-    frame_points.push_back (Point (x1, y1));
-    frame_points.push_back (Point (x2, y1));
-    frame_points.push_back (Point (x2, y2));
-    frame_points.push_back (Point (x1, y2));
-    frame_points.push_back (Point (x1, y1));
+    using namespace Gnome::CanvasHelpers;
 
     /* Data for the GdkBitmap to use as an outline stipple */
     static const char stipple_bits[] = {
-	0x02, 0x01, };
-
-    Gnome::CanvasPolygon *frame_item = new Gnome::CanvasPolygon (*group, frame_points);    
-    frame_item->set_width_units (1);
+	0x01, 0x02, };
 
     GdkBitmap *stipple = gdk_bitmap_create_from_data (NULL,
 						      stipple_bits,
-						      2, 2);    
-    frame_item->set_outline_stipple (stipple);
+						      2, 2);
+    
+    *(FormEditor::draw_rectangle (*group,
+				  x1 - 1, y1 - 1,
+				  x2, y2))
+	<< width_units (1)
+	<< outline_stipple (stipple)
+	<< outline_color (widget->usable ? GUIKACHU_FGC : GUIKACHU_FGC_DISABLED);
     gdk_bitmap_unref (stipple);
-
-    if (widget->usable)
-	frame_item->set_outline_color (GUIKACHU_FGC);
-    else
-	frame_item->set_outline_color (GUIKACHU_FGC_DISABLED);
     
     int text_x = x1 + 3;
     int text_y = y1 + height / 2 - 1;
@@ -87,7 +78,7 @@ void SelectorTriggerCanvasItem::update ()
 	       text_x, text_y,
 	       widget->usable,
 	       GTK_ANCHOR_WEST,
-	       width, height);
+	       width - 3, height);
 
     set_canvas_item (group);
 }
