@@ -1,4 +1,4 @@
-//$Id: selector-trigger-prop.cc,v 1.5 2001/09/01 13:10:16 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-prop.cc,v 1.6 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -68,8 +68,7 @@ SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res)
     ResizeableProperties::add_controls (res, *proptable);
     
     proptable->show ();
-    property_editor = manage (proptable);
-    gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
+    property_editor = proptable;
 }
 
 SelectorTriggerProperties::~SelectorTriggerProperties ()
