@@ -1,4 +1,4 @@
-//$Id: selector-trigger-prop.h,v 1.2 2001/04/30 17:54:27 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-prop.h,v 1.4 2001/08/19 15:02:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,10 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_PROP_H
 #define GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_PROP_H
 
-#include <string>
-#include <iostream>
-#include <sigc++/object.h>
-
 namespace Guikachu
 {
     namespace GUI
@@ -42,7 +38,7 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class SelectorTriggerProperties: public SigC::Object
+	    class SelectorTriggerProperties
 	    {
 		Gtk::Widget *property_editor;
 	    public:
