@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.13 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.14 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -172,13 +172,13 @@ void SelectorTrigger::save_rcp (std::ostream &ostr) const
     g_free (width_str);
 }
 
-int SelectorTrigger::get_auto_width ()
+int SelectorTrigger::get_auto_width () const
 {
     int text_width = get_string_width (font, text);
     return 6 + text_width;
 }
 
-int SelectorTrigger::get_auto_height ()
+int SelectorTrigger::get_auto_height () const
 {
     int text_height = get_font_height (font);
     return text_height + 1;
