@@ -1,4 +1,4 @@
-//$Id: table-canvas.cc,v 1.4 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.cc,v 1.6 2001/11/18 10:59:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,25 +40,47 @@ void TableCanvasItem::update ()
 	delete group;
 
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
+
+    const std::vector<int> &columns = widget->column_width;
+
     
-    int width = widget->get_display_width ();
-    int height = widget->get_display_height ();
-
-    /* Don't ask about the +1, I have no idea... */
-    int x1 = widget->x;
-    int x2 = x1 + width;
-    int y1 = widget->y;
-    int y2 = y1 + height;
-
-    /* A Polygon is used instead of a Rectangle to get mouse events
-     * inside the "hollow" area
-     */
-    static const char stipple_bits[] = {
-	0x02, 0x01, };
+    using Gnome::Art::Point;
+    using namespace Gnome::CanvasHelpers;
+    
+    static const char stipple_bits[] = { 0x02, 0x01, };
     GdkBitmap *stipple = gdk_bitmap_create_from_data (NULL,
 						      stipple_bits,
 						      2, 2);
     
+    /* Column separators */
+    int width  = 0;
+    int height = widget->num_rows * 11;
+
+    int x1 = widget->x;
+    int y1 = widget->y;
+    int y2 = y1 + height;
+    
+    int num_columns = widget->num_columns;
+    for (int i = 0; i < num_columns; i++)
+    {
+	width += columns[i] + 1;
+	int line_x = x1 + width;
+	
+	Gnome::CanvasPoints line_points;
+	
+	line_points.push_back (Point (line_x, y1));
+	line_points.push_back (Point (line_x, y2));
+			       
+	*(new Gnome::CanvasLine (*group, line_points))
+	    << fill_color (GUIKACHU_FGC)
+	    << fill_stipple (stipple);
+    }
+
+    int x2 = x1 + width;
+
+    /* A Polygon is used instead of a Rectangle to get mouse events
+     * inside the "hollow" area
+     */
     Gnome::CanvasPoints frame_points;
     using Gnome::Art::Point;
     using namespace Gnome::CanvasHelpers;
@@ -72,9 +94,9 @@ void TableCanvasItem::update ()
     *(new Gnome::CanvasPolygon (*group, frame_points))
 	<< outline_color (GUIKACHU_FGC)
 	<< outline_stipple (stipple);
-
+    
     /* Row separators */
-    int row_step = height / widget->num_rows;
+    int row_step = 11;
     int row_y = y1;
     for (int i = 0; i < widget->num_rows; i++)
     {
@@ -90,24 +112,6 @@ void TableCanvasItem::update ()
 	row_y += row_step;
     }
     
-    /* Column separators */
-    int line_x = x1;
-    const std::vector<int> &columns = widget->column_width;
-    int num_columns = widget->num_columns;
-    for (int i = 0; i < num_columns; i++)
-    {
-	line_x += columns[i];
-	
-	Gnome::CanvasPoints line_points;
-	
-	line_points.push_back (Point (line_x, y1));
-	line_points.push_back (Point (line_x, y2));
-			       
-	*(new Gnome::CanvasLine (*group, line_points))
-	    << fill_color (GUIKACHU_FGC)
-	    << fill_stipple (stipple);
-    }
-
     gdk_bitmap_unref (stipple);
     
     set_canvas_item (group);
