@@ -1,4 +1,4 @@
-//$Id: table-canvas.h,v 1.1 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.h,v 1.2 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,7 +36,7 @@ namespace Guikachu
 	    public:
 		TableCanvasItem (Widgets::Table   *widget,
 				 FormEditor::Form *form);
-	    private:
+	    protected:
 		virtual void update ();
 	    };
 	}
