@@ -1,4 +1,4 @@
-//$Id: table-prop.cc,v 1.5 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: table-prop.cc,v 1.6 2001/11/15 23:25:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,7 +33,6 @@
 #include "form-editor.h"
 
 #include "widget-prop.h"
-#include "resizeable-prop.h"
 #include <vector>
 
 using namespace Guikachu::GUI::FormEditor;
@@ -92,9 +91,6 @@ TableProperties::TableProperties (Table *res)
     /* Position */
     WidgetProperties::add_position_controls (res, *proptable);
 
-    /* Size */
-    ResizeableProperties::add_controls (res, *proptable);
-
     // FIXME: Add uline accelerators to the tabs
     notebook->pages ().push_back (
 	Gtk::Notebook_Helpers::TabElem (*manage (proptable),
