@@ -1,4 +1,4 @@
-//$Id: table.h,v 1.5 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: table.h,v 1.7 2001/11/15 23:25:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,8 +38,7 @@ namespace Guikachu
 {
     namespace Widgets
     {
-	class Table: public Widget,
-		     public Resizeable
+	class Table: public Widget
 	{
 	    GUI::FormEditor::TableProperties *editor;
 
@@ -56,10 +55,6 @@ namespace Guikachu
 	    Property<int>               num_rows;
 	    Property<int>               num_columns;
 	    Property<std::vector<int> > column_width;
-
-	protected:
-	    virtual int get_auto_width  ();
-	    virtual int get_auto_height ();
 	    
 	private:
 	    // Persistance
