@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.h,v 1.1 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.h,v 1.3 2001/10/18 20:41:43 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,9 +22,6 @@
 #include "form-editor/text-field.h"
 #include "form-editor/canvasitem.h"
 
-using Guikachu::Widgets::TextField;
-using namespace Guikachu::GUI::FormEditor;
-
 namespace Guikachu
 {
     namespace GUI
@@ -36,10 +33,12 @@ namespace Guikachu
 		Widgets::TextField *widget;
 		Gnome::CanvasGroup *group;
 	    public:
-		TextFieldCanvasItem (Widgets::TextField *widget,
-				     FormEditor::Form   *form);
-	    private:
+		TextFieldCanvasItem (Widgets::TextField    *widget,
+				     GUI::FormEditor::Form *form);
+	    protected:
 		virtual void update ();
+		virtual void get_bounds (int &x1, int &y1,
+					 int &x2, int &y2);
 	    };
 	}
     }
