@@ -1,4 +1,4 @@
-//$Id: text-field.h,v 1.4 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: text-field.h,v 1.5 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -66,11 +66,11 @@ namespace Guikachu
 	    Property<bool> has_scrollbar;
 
 	protected:
-	    virtual int get_auto_width  ();
-	    virtual int get_auto_height ();
+	    virtual int get_auto_width  () const;
+	    virtual int get_auto_height () const;
 
 	public:
-	    virtual int get_display_height ();
+	    virtual int get_display_height () const;
 	    
 	private:
 	    // Persistance
