@@ -1,4 +1,4 @@
-//$Id: textual.cc,v 1.1 2001/08/18 20:32:15 cactus Exp $ -*- c++ -*-
+//$Id: textual.cc,v 1.2 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 using namespace Guikachu::Widgets;
 
 Textual::Textual (SigC::Signal0<void> &changed,
-		  const string& default_text = ""):
+		  const std::string   &default_text = ""):
     text (changed, default_text),
     font (changed, 0)
 {
