@@ -1,4 +1,4 @@
-//$Id: textual.h,v 1.1 2001/08/18 20:32:15 cactus Exp $ -*- c++ -*-
+//$Id: textual.h,v 1.2 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,13 +30,13 @@ namespace Guikachu
 	{
 	protected:
 	    Textual (SigC::Signal0<void> &changed,
-		     const string& default_text = "");
+		     const std::string   &default_text = "");
 
 	public:
 	    virtual ~Textual () {};
 
-	    Property<string> text;
-	    Property<int>    font;
+	    Property<std::string> text;
+	    Property<int>         font;
 	};
     }
 }
