@@ -1,4 +1,4 @@
-//$Id: widget-util.h,v 1.2 2001/10/16 16:11:49 cactus Exp $ -*- c++ -*-
+//$Id: widget-util.h,v 1.3 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,11 +27,11 @@ namespace Guikachu
 {
     namespace Widgets
     {
-	const string type_id_from_type       (Type          type)    G_GNUC_CONST;
-	Type         type_from_type_id       (const string &type_id);
+	const std::string type_id_from_type      (Type               type) G_GNUC_CONST;
+	Type              type_from_type_id      (const std::string &type_id);
 
-	const string display_name_from_type  (Type          type)    G_GNUC_CONST;
-	const char * const * type_icon       (Type          type)    G_GNUC_CONST;
+	const std::string display_name_from_type (Type               type) G_GNUC_CONST;
+	const char * const * type_icon           (Type               type) G_GNUC_CONST;
     }
 }
 
