@@ -1,4 +1,4 @@
-//$Id: form-res-io.cc,v 1.22 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: form-res-io.cc,v 1.23 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,9 +36,9 @@ bool Form::load (StorageNode &node)
 	if (curr_node.name () == "title")
 	    title = curr_node.get_content ();
 	else if (curr_node.name () == "help")
-	    help_id = curr_node.get_prop<string> ("id");
+	    help_id = curr_node.get_prop<std::string> ("id");
 	else if (curr_node.name () == "menu")
-	    menu_id = curr_node.get_prop<string> ("id");
+	    menu_id = curr_node.get_prop<std::string> ("id");
 	else if (curr_node.name () == "modal")
 	    modal = true;
 	else if (curr_node.name () == "frame")
@@ -54,7 +54,7 @@ bool Form::load (StorageNode &node)
 	}
 	else if (curr_node.name () == "widgets")
 	{
-	    def_button = curr_node.get_prop <string> ("default");
+	    def_button = curr_node.get_prop <std::string> ("default");
 	    
 	    for (StorageNode widget_node = curr_node.children ();
 		 widget_node; widget_node++)
@@ -77,7 +77,7 @@ Widgets::Widget* Form::load_widget (StorageNode &node)
 {
     Widgets::Widget *widget = 0;
     
-    const string &id = node.get_prop<string> ("id");
+    const std::string &id = node.get_prop<std::string> ("id");
 
     if (id == "")
     {
@@ -137,7 +137,7 @@ void Form::save (StorageNode &node) const
 	if (def_button != "")
 	    widgetlist_node.set_prop ("default", def_button);
 	
-	for (set<Widgets::Widget*>::const_iterator i = widgets.begin ();
+	for (std::set<Widgets::Widget*>::const_iterator i = widgets.begin ();
 	     i != widgets.end (); i++)
 	    save_widget (widgetlist_node, *i);
     }
@@ -146,20 +146,20 @@ void Form::save (StorageNode &node) const
 void Form::save_widget (StorageNode     &node,
 			Widgets::Widget *widget) const
 {
-    string curr_node_name = Widgets::type_id_from_type (widget->get_type ());
+    std::string curr_node_name = Widgets::type_id_from_type (widget->get_type ());
     
     StorageNode widget_node = node.add_node (curr_node_name);
     widget_node.set_prop ("id", widget->id);
     widget->save (widget_node);
 }
 
-void Form::save_rcp (ostream &ostr) const
+void Form::save_rcp (std::ostream &ostr) const
 {
-    ostr << "FORM ID " << id << endl;
+    ostr << "FORM ID " << id << std::endl;
 
     ostr << "AT (" << x     << " " << y      << " "
-	           << width << " " << height << ")" << endl;
-    ostr << "USABLE" << endl;
+	           << width << " " << height << ")" << std::endl;
+    ostr << "USABLE" << std::endl;
 
     if (modal)
 	ostr << "MODAL ";
@@ -173,27 +173,27 @@ void Form::save_rcp (ostream &ostr) const
 	ostr << "SAVEBEHIND ";
     else
 	ostr << "NOSAVEBEHIND ";
-    ostr << endl;
+    ostr << std::endl;
     
     if (help_id != "")
-	ostr << "HELPID " << help_id << endl;
+	ostr << "HELPID " << help_id << std::endl;
 
     if (menu_id != "")
-	ostr << "MENUID " << menu_id << endl;
+	ostr << "MENUID " << menu_id << std::endl;
 
     if (def_button != "")
-	ostr << "DEFAULTBTNID " << def_button << endl;
+	ostr << "DEFAULTBTNID " << def_button << std::endl;
     
     if (widgets.size () || (title != ""))
     {
-	ostr << "BEGIN" << endl;
-	ostr << "  TITLE \"" << title << "\"" << endl;
+	ostr << "BEGIN" << std::endl;
+	ostr << "  TITLE \"" << title << "\"" << std::endl;
 	
-	for (set<Widgets::Widget*>::const_iterator i = widgets.begin ();
+	for (std::set<Widgets::Widget*>::const_iterator i = widgets.begin ();
 	     i != widgets.end (); i++)
 	    ostr << *i;
 	
-	ostr << "END" << endl;
+	ostr << "END" << std::endl;
     }
-    ostr << endl;
+     ostr << std::endl;
 }
