@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.16 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.17 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,21 +47,21 @@ namespace Guikachu
 	{
 	    Guikachu::GUI::FormWindow *gui;
 
-	    set<Widgets::Widget*>  widgets;
+	    std::set<Widgets::Widget*> widgets;
 
 	public:
-	    Form (const string& name);
+	    Form (const std::string& name);
 	    virtual ~Form ();
 	    
 	    virtual Type get_type () const { return RESOURCE_FORM; };
 	    virtual void show_ui ();
 
 	    // Widget managment
-	    const set<Widgets::Widget*>& get_widgets () const { return widgets; };
-	    Widgets::Widget*             get_widget (const string& id) const;
+	    const std::set<Widgets::Widget*>& get_widgets () const { return widgets; };
+	    Widgets::Widget*                  get_widget  (const std::string& id) const;
 	    
-	    Widgets::Widget* create_widget (Widgets::Type  type,
-					    const string  &id = "");
+	    Widgets::Widget* create_widget (Widgets::Type type,
+					    std::string   id = "");
 	    void remove_widget (Widgets::Widget *widget);
 
 	    SigC::Signal1<void, Widgets::Widget*> widget_created;
@@ -69,7 +69,7 @@ namespace Guikachu
 	    SigC::Signal0<void> widget_changed;
 
 	    // Properties
-	    Property<string>        title;
+	    Property<std::string>   title;
 	    Properties::ResourceRef help_id;
 	    Properties::ResourceRef menu_id;
 
@@ -88,7 +88,7 @@ namespace Guikachu
 	    // Persistance
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 
 	    Widgets::Widget* load_widget (StorageNode     &node);
 	    void             save_widget (StorageNode     &node,
