@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.cc,v 1.7 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.cc,v 1.8 2001/11/18 10:59:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,6 +30,10 @@
 
 #include "form-editor/widget-util.h"
 
+namespace {
+#include "pixmaps/form.xpm"
+}
+
 using namespace Guikachu::GUI::FormWindow_Helpers;
 
 /***********************************
@@ -47,10 +51,8 @@ WidgetTreeItem::WidgetTreeItem (Widgets::Widget *widget_):
     label.set_alignment (0, 0.5);
     box->pack_start (*manage (pixmap), false);
     box->pack_start (label);
-    box->show_all ();
-    
+    box->show_all ();    
     add (*manage (box));
-    
 
     set_user_data (widget);
 
@@ -96,19 +98,28 @@ void WidgetTreeItem::widget_selected_cb (bool selected)
  ***********************************/
 
 TopTreeItem::TopTreeItem (Resources::Form *res_):
-    Gtk::TreeItem (res_->id),
     res (res_)
 {
+    Gtk::Pixmap *pixmap = new Gtk::Pixmap (form_xpm);
+    Gtk::Box    *box    = new Gtk::HBox   (false, 5);
+
+    label.set_alignment (0, 0.5);
+    box->pack_start (*manage (pixmap), false);
+    box->pack_start (label);
+    box->show_all ();
+    add (*manage (box));
+    
     set_user_data (res);
     
     res->changed.connect (slot (this, &TopTreeItem::update));
     button_press_event.connect (slot (this, &TopTreeItem::button_press_cb));
+
+    update ();
 }
 
 void TopTreeItem::update ()
 {
-    remove ();
-    add_label (res->id);
+    label.set_text (res->id);
 }
 
 int TopTreeItem::button_press_cb (GdkEventButton *e)
