@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.21 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.22 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -57,7 +57,7 @@ namespace Guikachu
 	    FormEditor::Form           *form;
 
 	    Widgets::Widget            *edited_widget;
-	    set<Widgets::Widget*>       selected_widgets;
+	    std::set<Widgets::Widget*>  selected_widgets;
 	    SigC::Connection            edited_widget_changed_conn;
 	    
 	    Gnome::CanvasItem          *canvas_overlay;
