@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.11 2001/11/04 18:55:52 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.13 2001/11/06 17:04:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,7 +23,7 @@
 
 #include <fcntl.h>
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
@@ -48,8 +48,8 @@ namespace {
     
 static bool check_file (FileEntry& file)
 {
-    bool success = true;
-    string filename = file.filename;
+    bool        success  = true;
+    std::string filename = file.filename;
 
     /* For _REGULAR and _FONT */
     int fd = -1;
@@ -68,7 +68,7 @@ static bool check_file (FileEntry& file)
 	break;
 	
     case FILETYPE_GLADE:
-	filename = string (GLADEDIR) + "/" + filename;
+	filename = std::string (GLADEDIR) + "/" + filename;
 	gui = glade_xml_new (filename.c_str (), 0);
 	if (!gui)
 	    success = false;
@@ -77,7 +77,7 @@ static bool check_file (FileEntry& file)
 	break;
 	
     case FILETYPE_FONT:
-	filename = string (FONTDIR) + "/" + filename;
+	filename = std::string (FONTDIR) + "/" + filename;
 	fd = open (filename.c_str (), 0);
 	if (fd == -1)
 	    success = false;
@@ -134,18 +134,18 @@ int main (int argc, char **argv)
     if (!check_files ())
 	return -1;
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/guikachu.png");
 #endif
     
     GUI::MainWin main_win;
     
-    const vector<string> &filenames = app.get_cmd_arguments ();
-    string filename = "";
+    const std::vector<std::string> &filenames = app.get_cmd_arguments ();
+    std::string filename = "";
 
     if (filenames.size ())
     {
-	for (vector<string>::const_iterator i = filenames.begin ();
+	for (std::vector<std::string>::const_iterator i = filenames.begin ();
 	     i != filenames.end (); i++)
 	    filename = *i;
 	    
