@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.12 2001/11/14 15:10:36 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.14 2001/11/19 05:48:49 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -48,26 +48,30 @@ bool GUI::MainWin::check_save ()
 	    "Would you like to save it?");
 
     Gnome::Dialog *dialog = new Gnome::MessageBox (
-	message, GNOME_MESSAGE_BOX_QUESTION, std::vector<string>());
-    dialog->append_button (_("Save"), GNOME_STOCK_PIXMAP_SAVE);
+	message, GNOME_MESSAGE_BOX_WARNING, std::vector<string>());
+
+    static const int save_btn = 2;
+    static const int discard_btn = 0;
+    static const int cancel_btn = 1;
+    
     dialog->append_button (_("Discard"), GNOME_STOCK_PIXMAP_TRASH);
     dialog->append_button (GNOME_STOCK_BUTTON_CANCEL);
+    dialog->append_button (_("Save"), GNOME_STOCK_PIXMAP_SAVE);
 
     dialog->set_modal (true);
-    dialog->set_default (0);
-    gnome_dialog_grab_focus (dialog->gtkobj (), 0);
+    dialog->set_default (save_btn);
+    gnome_dialog_grab_focus (dialog->gtkobj (), save_btn);
     
     response = dialog->run_and_close ();
 
-    if (response == 2 ||
-	response == -1) // Cancel
+    if (response == cancel_btn || response == -1) // Cancel
 	return false;
 
-    if (response == 1) // No
+    if (response == discard_btn)
 	if (in_exit)
 	    Gnome::Main::quit ();
     
-    if (response == 0) // Yes
+    if (response == save_btn)
     {
 	save_cb ();
 	if (ResourceManager::is_dirty ())
@@ -170,6 +174,7 @@ void GUI::MainWin::export_cb ()
     fs->set_transient_for (*this);
     fs->set_modal (true);
     fs->show ();
+    Gtk::Main::run ();
 }
 
 
