@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.14 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.15 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,6 +40,7 @@
 #include <sigc++/rettype.h>
 
 using namespace Guikachu;
+using std::string;
 
 GUI::MainWin::MainWin ():
     Gnome::App ("Guikachu", "Guikachu"),
@@ -50,7 +51,7 @@ GUI::MainWin::MainWin ():
     using namespace Gnome;
     
     /* File menu */
-    list <UI::Info> m_file;
+    std::list <UI::Info> m_file;
     m_file.push_back (MenuItems::New    (_("_New project"), _("Create a new project"),
 					 slot (this, &MainWin::new_cb)));
     m_file.push_back (MenuItems::Open   (slot (this, &MainWin::load_cb)));
@@ -65,11 +66,11 @@ GUI::MainWin::MainWin ():
 					       (GdkEventAny*)0)));
 
     /* Help menu */
-    list <UI::Info> m_help;
+    std::list <UI::Info> m_help;
     m_help.push_back (MenuItems::About (slot (&show_about)));
 
     /* Create the menu */
-    list <UI::SubTree> menubar;
+    std::list <UI::SubTree> menubar;
     menubar.push_back (Menus::File (m_file));
     menubar.push_back (Menus::Help (m_help));
     create_menus (menubar);
@@ -79,7 +80,7 @@ GUI::MainWin::MainWin ():
     install_menu_hints ();
 
     /* Create the tool bar */
-    list <UI::Info> toolbar;
+    std::list <UI::Info> toolbar;
     toolbar.push_back (UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_ADD),
 				 _("Add"),
 				 slot (this, &MainWin::add_cb),
@@ -125,8 +126,8 @@ GUI::MainWin::MainWin ():
     create_tree_for_type (Resources::RESOURCE_BLOB, _("Blobs"));
 
     /* Fill with existing resources */
-    set<Resources::Resource*> resources = ResourceManager::get_resources ();
-    for (set<Resources::Resource*>::iterator i = resources.begin ();
+    std::set<Resources::Resource*> resources = ResourceManager::get_resources ();
+    for (std::set<Resources::Resource*>::iterator i = resources.begin ();
 	 i != resources.end (); i++)
 	resource_created_cb ((*i));
     
@@ -172,7 +173,7 @@ void GUI::MainWin::create_tree_for_type (Resources::Type type,
 					 const string& category_name)
 {
     Gtk::TreeItem *subtree_item = new Gtk::TreeItem (category_name);
-    pair<subtree_map::iterator, bool> success;
+    std::pair<subtree_map::iterator, bool> success;
     
     success = subtrees.insert (subtree_map::value_type (type, subtree_item));
     
@@ -210,7 +211,7 @@ void GUI::MainWin::update_title ()
 
 void GUI::show_about ()
 {
-    list<string> authors;
+    std::list<string> authors;
     authors.push_back ("Gerg rdi <cactus@cactus.rulez.org>");
 
     Gnome::About *about = new Gnome::About ("Guikachu", VERSION,
