@@ -1,4 +1,4 @@
-//$Id: mainwin.h,v 1.5 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.h,v 1.6 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,24 +40,24 @@ namespace Guikachu
     {
 	class MainWin: public Gnome::App
 	{
-	    typedef map<Resources::Type, Gtk::TreeItem*> subtree_map;
-	    typedef map<Resources::Resource*, Guikachu::GUI::TreeItem*> treeitem_map;
+	    typedef std::map<Resources::Type, Gtk::TreeItem*>                subtree_map;
+	    typedef std::map<Resources::Resource*, Guikachu::GUI::TreeItem*> treeitem_map;
 	    
 	    Gtk::Tree     *main_tree;
 	    Gtk::TreeItem *top_item;
 	    subtree_map    subtrees;
 	    treeitem_map   treeitems;
 
-	    string filename;
-	    bool in_exit;
+	    std::string filename;
+	    bool        in_exit;
 	    
 	public:
 	    MainWin ();
-	    void set_filename (const string& filename);
+	    void set_filename (const std::string& filename);
 	    
 	private:
-	    void create_tree_for_type (Resources::Type type,
-				       const string& category_name);
+	    void create_tree_for_type (Resources::Type    type,
+				       const std::string &category_name);
 
 	    void update_title ();
 	    void resource_created_cb (Resources::Resource *res);
@@ -72,16 +72,16 @@ namespace Guikachu
 	    void save_as_cb ();
 	    void export_cb ();
 
-	    void filesel_open_cb (Gtk::FileSelection *fs);
-	    void filesel_save_cb (Gtk::FileSelection *fs);
-	    void filesel_close_cb (Gtk::FileSelection *fs);
+	    void filesel_open_cb   (Gtk::FileSelection *fs);
+	    void filesel_save_cb   (Gtk::FileSelection *fs);
+	    void filesel_close_cb  (Gtk::FileSelection *fs);
 	    void filesel_export_cb (Gtk::FileSelection *fs);
 
 	    bool check_save ();
 	};
 
 	void show_about ();
-	void show_error (const string& message);
+	void show_error (const std::string& message);
     }
 }
 
