@@ -1,4 +1,4 @@
-//$Id: menu-res.cc,v 1.11 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.12 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,9 @@
 
 using namespace Guikachu;
 using namespace Guikachu::Resources;
+using std::string;
+using std::vector;
+using std::ostream;
 
 Menu::Menu (const string& id):
     Resource (id),
@@ -184,32 +187,32 @@ void Menu::save (StorageNode &node) const
 
 void Menu::save_rcp (ostream &ostr) const
 {
-    ostr << "MENU ID " << id << endl;
+    ostr << "MENU ID " << id << std::endl;
 
-    ostr << "BEGIN" << endl;
+    ostr << "BEGIN" << std::endl;
 
     for (vector<Submenu>::const_iterator i = submenus.begin ();
 	 i != submenus.end (); i++)
     {
-	ostr << "  PULLDOWN \"" << i->label << "\"" << endl;
+	ostr << "  PULLDOWN \"" << i->label << "\"" << std::endl;
 	
-	ostr << "  BEGIN" << endl;
+	ostr << "  BEGIN" << std::endl;
 	for (vector<MenuItem>::const_iterator j = i->items.begin ();
 	     j != i->items.end (); j++)
 	{
 	    if (j->separator)
-		ostr << "    MENUITEM SEPARATOR" << endl;
+		ostr << "    MENUITEM SEPARATOR" << std::endl;
 	    else
 	    {
 		ostr << "    MENUITEM \"" << j->label << "\" ID " << j->id;
 		if (j->shortcut)
 		    ostr << " \"" << j->shortcut << "\"";
-		ostr << endl;
+		ostr << std::endl;
 	    }
 	}
-	ostr << "  END" << endl;
+	ostr << "  END" << std::endl;
     }
     
-    ostr << "END" << endl
-	 << endl;
+    ostr << "END" << std::endl
+	 << std::endl;
 }
