@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.18 2001/11/18 10:59:50 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.19 2001/11/25 19:50:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -472,8 +472,8 @@ void GUI::MenuWindow::btn_submenu_cb ()
     
     if (clist_rows[row].is_submenu)
     {
-	new_index = submenus.begin () + index;
-	new_row = row;
+	new_index = submenus.begin () + index + 1;
+	new_row = row + submenus[clist_rows[row].index].items.size () + 1;
     } else {
 	new_index = submenus.begin () + clist_rows[row].parent_index + 1;
 
