@@ -1,4 +1,4 @@
-//$Id: menu-win.h,v 1.7 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.h,v 1.8 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -59,13 +59,13 @@ namespace Guikachu
 	    
 	    struct RowData
 	    {
-		bool is_submenu;
+		bool         is_submenu;
 		unsigned int index;
 		unsigned int parent_index;
 	    };
 	    
-	    vector<RowData> clist_rows;
-	    vector<Resources::Submenu> submenus;
+	    std::vector<RowData> clist_rows;
+	    std::vector<Resources::Submenu> submenus;
 
 	public:
 	    MenuWindow (Guikachu::Resources::Menu *res);
