@@ -1,4 +1,4 @@
-//$Id: property.h,v 1.7 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
+//$Id: property.h,v 1.8 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,7 +25,6 @@
 
 namespace Guikachu
 {
-
     template <class T>
     class Property
     {
@@ -78,24 +77,24 @@ namespace Guikachu
 	inline value_t operator-= (const value_t &other) { set_val (value - other); return value; };
 	inline value_t operator-= (const self_t  &other) { set_val (value - other.value); return value; };
 	
-	friend ostream & operator<<<value_t> (ostream &ostr, const Property<value_t> &prop);
+	friend std::ostream & operator<<<value_t> (std::ostream &ostr, const Property<value_t> &prop);
     };
 
     template<class T>
-    inline ostream & operator<< (ostream &ostr, const Property<T> &prop)
+    inline std::ostream & operator<< (std::ostream &ostr, const Property<T> &prop)
     {
 	ostr << prop.value;
 	return ostr;
     }
 
-    class ID: public Property<string>
+    class ID: public Property<std::string>
     {
     public:
-	ID (notify_signal_t &notify_signal,
-	    const string    &value);
+	ID (notify_signal_t   &notify_signal,
+	    const std::string &value);
 	
-	inline const string& operator= (const string &value_) { set_val (value_); return value; };
-	virtual void set_val (const string &value);
+	inline const std::string& operator= (const std::string &value_) { set_val (value_); return value; };
+	virtual void set_val (const std::string &value);
     };
 }
 
