@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.17 2001/11/10 15:13:00 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.18 2001/11/17 14:22:44 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -174,7 +174,8 @@ void ResourceManager::export_rcp (const std::string &filename)
     const char* date_str = ctime (&curr_date);
     
     fout << "/*" << std::endl;
-    fout << " * This file was created by Guikachu. Do not edit it manually." << std::endl;
+    fout << " * This file was created by Guikachu " << VERSION
+	 << ". Do not edit it manually." << std::endl;
     fout << " * Creation date: " << date_str; // ctime ()'s return value ends in \n
     fout << " */" << std::endl << std::endl;;
     
