@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.13 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.17 2001/11/09 23:55:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,23 +32,44 @@
 
 using namespace Guikachu;
 
-map<string_case, Resources::Resource*> ResourceManager::resource_map;
-set<string_case> ResourceManager::id_set;
-Resources::Application *ResourceManager::app = 0;
+#define ASCII_TOUPPER(c)  (((c) >= 97 && (c) <= 122) ? (c) - 32 : (c))
+
+bool NoCase::operator () (const std::string &x, const std::string &y) const
+{
+    std::string::const_iterator p = x.begin ();
+    std::string::const_iterator q = y.begin ();
+
+    while (p != x.end () && q != y.end () &&
+	   ASCII_TOUPPER (*p) == ASCII_TOUPPER (*q))
+    {
+	p++;
+	q++;
+    }
+
+    if (p == x.end ()) return q != y.end ();
+    if (q == y.end ()) return false;
+
+    return ASCII_TOUPPER (*p) < ASCII_TOUPPER (*q);
+}
+
+ResourceManager::resource_map_t  ResourceManager::resource_map;
+ResourceManager::id_set_t        ResourceManager::id_set;
+Resources::Application          *ResourceManager::app = 0;
+bool                             ResourceManager::dirty = false;
+
 SigC::Signal1<void, Resources::Resource*> ResourceManager::resource_created;
 SigC::Signal1<void, Resources::Resource*> ResourceManager::resource_removed;
 
-bool ResourceManager::dirty = false;
-
-string ResourceManager::create_id (const string& prefix)
+std::string ResourceManager::create_id (const std::string &prefix)
 {
     unsigned int num = 0;
-    string ret_val;
+    std::string ret_val;
     gchar *curr_name;
-
+    const char *prefix_str = prefix.c_str ();
+    
     for (num = 1; num != 0; num++)
     {
-	curr_name = g_strdup_printf ("%s%d", prefix.c_str (), num);
+	curr_name = g_strdup_printf ("%s%d", prefix_str, num);
 
 	if (id_set.find (curr_name) == id_set.end ())
 	{
@@ -66,7 +87,7 @@ string ResourceManager::create_id (const string& prefix)
     return ret_val;
 }
 
-bool ResourceManager::register_id (const string& id)
+bool ResourceManager::register_id (const std::string &id)
 {
     if (id_set.find (id) != id_set.end ())
     {
@@ -80,30 +101,28 @@ bool ResourceManager::register_id (const string& id)
     return true;
 }
 
-void ResourceManager::unregister_id (const string& id)
+void ResourceManager::unregister_id (const std::string &id)
 {
     id_set.erase (id);
 }
 
-string ResourceManager::validate_id (const string &id)
+std::string ResourceManager::validate_id (std::string id)
 {
-    string valid_id = id;
-    
-    string allowed_characters =
+    std::string allowed_characters =
 	"abcdefghijklmnopqrstuvwxyz_ABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789";
     
-    for (string::iterator i = valid_id.begin ();
-	 i != valid_id.end (); i++)
-	if (allowed_characters.find (*i) == string::npos)
+    for (std::string::iterator i = id.begin ();
+	 i != id.end (); i++)
+	if (allowed_characters.find (*i) == std::string::npos)
 	    *i = '_';
 
-    return valid_id;
+    return id;
 }
 
-Resources::Resource* ResourceManager::create_resource (Resources::Type  type,
-						       const string    &id_ = "")
+Resources::Resource* ResourceManager::create_resource (Resources::Type type,
+						       std::string     id = "")
 {
-    string id = validate_id (id_);
+    id = validate_id (id);
     
     if (id == "")
 	id = create_id (Resources::type_id_from_type (type));
@@ -111,8 +130,8 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type  type,
     if (!register_id (id))
 	return 0;
 
-    string real_id = id;
-    for (string::iterator i = real_id.begin ();
+    std::string real_id = id;
+    for (std::string::iterator i = real_id.begin ();
 	 i != real_id.end (); i++)
     {
 	if (*i == ' ')
@@ -142,7 +161,7 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type  type,
 	break;
     }
     
-    resource_map.insert (pair<string_case, Resources::Resource*> (real_id, res));
+    resource_map.insert (std::make_pair (real_id, res));
 
     res->changed.connect (SigC::slot (&ResourceManager::resource_changed_cb));
 
@@ -153,15 +172,29 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type  type,
     return res;
 }
 
-bool ResourceManager::rename_resource (const string& old_id,
-				       const string& new_id)
+bool ResourceManager::rename_resource (const std::string &old_id,
+				       const std::string &new_id)
 {
     // No-ops: old_id == new_id
     if (old_id == new_id)
 	return true;
 
-    if (string_case (old_id) == string_case (new_id))
-	return true;
+    // No-ops: new_id and old_id differ only in case
+    {
+	std::string::const_iterator p = old_id.begin ();
+	std::string::const_iterator q = new_id.begin ();
+
+	while (p != old_id.end () &&
+	       q != new_id.end () &&
+	       ASCII_TOUPPER (*p) == ASCII_TOUPPER (*q))
+	{
+	    p++;
+	    q++;
+	}
+
+	if (p == old_id.end () && q == new_id.end ())
+	    return true;
+    }
 
     // Error: empty id
     if (new_id == "")
@@ -182,14 +215,14 @@ bool ResourceManager::rename_resource (const string& old_id,
     
     id_set.erase (old_id);
     id_set.insert (new_id);
-    
-    map<string_case, Resources::Resource*>::iterator map_i = resource_map.find (old_id);
+
+    resource_map_t::iterator map_i = resource_map.find (old_id);
     
     if (map_i != resource_map.end ())
     {
 	Resources::Resource *res = map_i->second;
 	resource_map.erase (map_i);
-	resource_map.insert (pair<string_case, Resources::Resource*> (new_id, res));
+	resource_map.insert (std::make_pair (new_id, res));
     }
 
     return true;
@@ -217,12 +250,12 @@ void ResourceManager::resource_changed_cb ()
     dirty = true;
 }
 
-set<Resources::Resource*> ResourceManager::get_resources ()
+std::set<Resources::Resource*> ResourceManager::get_resources ()
 {
-    set<Resources::Resource*> ret;
+    std::set<Resources::Resource*> ret;
 
-    for (map<string_case, Resources::Resource*>::const_iterator i =
-	     resource_map.begin (); i != resource_map.end (); i++)
+    for (resource_map_t::const_iterator i = resource_map.begin ();
+	 i != resource_map.end (); i++)
     {
 	ret.insert (i->second);
     }
@@ -230,13 +263,12 @@ set<Resources::Resource*> ResourceManager::get_resources ()
     return ret;
 }
 
-Resources::Resource* ResourceManager::get_resource (const string& id)
+Resources::Resource* ResourceManager::get_resource (const std::string &id)
 {
-    map<string_case, Resources::Resource*>::const_iterator found;
+    resource_map_t::const_iterator found = resource_map.find (id);
 
-    found = resource_map.find (id);
     if (found == resource_map.end ())
-	return NULL;
+	return 0;
     else
 	return found->second;
 }
