@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.10 2001/11/02 18:20:12 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.12 2001/11/09 23:55:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,6 @@ namespace Guikachu
 
 #include "resource.h"
 #include "app-res.h"
-#include "string-case.h"
 #include "storage-node.h"
 #include <map>
 #include <set>
@@ -35,29 +34,38 @@ namespace Guikachu
 
 namespace Guikachu
 {
+    class NoCase
+    {
+    public:
+	bool operator () (const std::string& x, const std::string& y) const;
+    };
+    
     class ResourceManager: public SigC::Object
     {
-	static map<string_case, Resources::Resource*> resource_map;
-	static set<string_case> id_set;
-	static bool dirty;
+	typedef std::map<std::string, Resources::Resource*, NoCase> resource_map_t;
+	typedef std::set<std::string, NoCase> id_set_t;
+	
+	static resource_map_t          resource_map;
+	static id_set_t                id_set;
+	static bool                    dirty;
 	static Resources::Application *app;
 
     public:
-	static Resources::Resource* create_resource (Resources::Type  type,
-						     const string    &id = "");
+	static Resources::Resource* create_resource (Resources::Type type,
+						     std::string     id = "");
 	static void remove_resource (Resources::Resource *resource);
-	static bool rename_resource (const string &old_id,
-				     const string &new_id);
+	static bool rename_resource (const std::string &old_id,
+				     const std::string &new_id);
 
-	static bool register_id   (const string &id);
-	static void unregister_id (const string &id);
+	static bool register_id   (const std::string &id);
+	static void unregister_id (const std::string &id);
 
-	static string create_id   (const string &prefix);
-	static string validate_id (const string &id);
+	static std::string create_id   (const std::string &prefix);
+	static std::string validate_id (std::string id);
 
-	static set<Resources::Resource*> get_resources ();
-	static Resources::Resource* get_resource (const string &id);
-	static Resources::Application* get_application () { return app; };
+	static std::set<Resources::Resource*> get_resources   ();
+	static Resources::Resource*           get_resource    (const std::string &id);
+	static Resources::Application*        get_application () { return app; };
 	
 	// Signals
 	static SigC::Signal1<void, Resources::Resource*> resource_created;
@@ -71,11 +79,11 @@ namespace Guikachu
 	    IO_INVALID
 	};
 	
-	static void reset ();
-	static bool is_dirty ();
-	static IOResult load (const string &filename);
-	static IOResult save (const string &filename);
-	static void export_rcp (const string &filename); 
+	static void     reset      ();
+	static bool     is_dirty   ();
+	static IOResult load       (const std::string &filename);
+	static IOResult save       (const std::string &filename);
+	static void     export_rcp (const std::string &filename); 
 
     private:
 	static void resource_changed_cb ();
