@@ -1,4 +1,4 @@
-//$Id: resource-util.cc,v 1.1 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: resource-util.cc,v 1.2 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,9 +20,9 @@
 
 using namespace Guikachu;
 
-const string Resources::type_id_from_type (Resources::Type type)
+const std::string Resources::type_id_from_type (Resources::Type type)
 {
-    string type_id;
+    std::string type_id;
     
     switch (type)
     {
