@@ -1,4 +1,4 @@
-//$Id: resource-util.h,v 1.2 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: resource-util.h,v 1.3 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,7 +26,7 @@ namespace Guikachu
 {
     namespace Resources
     {
-	const string type_id_from_type (Resources::Type type) G_GNUC_CONST;
+	const std::string type_id_from_type (Resources::Type type) G_GNUC_CONST;
     }
 }
 
