@@ -1,4 +1,4 @@
-//$Id: resource.cc,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: resource.cc,v 1.5 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,8 @@
 #include "resource.h"
 
 using namespace Guikachu;
+using std::string;
+using std::ostream;
 
 Resources::Resource::Resource (const string& id_):
     id (changed, id_)
