@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.13 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.14 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,6 @@
 
 #include <string>
 #include <iostream>
-#include <gnome-xml/tree.h>
 #include <sigc++/basic_signal.h>
 
 namespace Guikachu
@@ -52,7 +51,8 @@ namespace Guikachu
 	class Resource: public SigC::Object
 	{
 	protected:
-	    Resource (const string& id);
+	    Resource (const std::string& id);
+	    
 	public:
 	    virtual ~Resource () {};
 
@@ -72,13 +72,13 @@ namespace Guikachu
 	    // Persistance
 	    virtual bool load (StorageNode &node) = 0;
 	    virtual void save (StorageNode &node) const = 0;
-	    virtual void save_rcp (ostream &ostr) const = 0;
-	    friend ostream& operator<< (ostream &ostr, const Resource *res);
+	    virtual void save_rcp (std::ostream &ostr) const = 0;
+	    friend std::ostream& operator<< (std::ostream &ostr, const Resource *res);
 
 	    friend class ResourceManager;
 	};
 	
-	ostream& operator<< (ostream &ostr, const Resource* res);
+	std::ostream& operator<< (std::ostream &ostr, const Resource* res);
     };
 };
 
