@@ -1,4 +1,4 @@
-//$Id: session.cc,v 1.3 2001/11/04 21:30:21 cactus Exp $ -*- c++ -*-
+//$Id: session.cc,v 1.4 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -63,7 +63,7 @@ Guikachu::Main::~Main ()
     poptFreeContext (ctx);
 }
 
-const vector<string>& Guikachu::Main::get_cmd_arguments ()
+const std::vector<std::string>& Guikachu::Main::get_cmd_arguments ()
 {
     return cmd_arguments;
 }
@@ -89,19 +89,16 @@ void Guikachu::Main::save_open_file ()
     Gnome::Client* session_client = Gnome::Client::master_client ();
     if (session_client->is_connected ())
     {
-	vector<string> argv;
+	std::vector<std::string> argv;
 	argv.push_back (cmd_self);
 	argv.push_back (last_filename);
-
-	cerr << "argv[0]: " << argv[0] << endl;
-	cerr << "argv[1]: " << argv[1] << endl;	
 	
 	session_client->set_clone_command (argv);
 	session_client->set_restart_command (argv);
     }
 }
 
-void Guikachu::Main::set_filename (const string &filename)
+void Guikachu::Main::set_filename (const std::string &filename)
 {
     last_filename = filename;
 }
