@@ -1,4 +1,4 @@
-//$Id: session.h,v 1.2 2001/11/04 18:55:52 cactus Exp $ -*- c++ -*-
+//$Id: session.h,v 1.3 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,21 +27,21 @@ namespace Guikachu
 {
     class Main: public Gnome::Main
     {
-	static Main    *instance_;
+	static Main *instance_;
 
-	poptContext     ctx;
-	string          cmd_self;
-	vector<string>  cmd_arguments;
-	string          last_filename;
+	poptContext              ctx;
+	std::string              cmd_self;
+	std::vector<std::string> cmd_arguments;
+	std::string              last_filename;
 	
     public:
 	Main (int argc, char **argv);
-	virtual ~Main ();
 	static inline Main *instance () { return instance_; };
+	virtual ~Main ();
 
-	const vector<string>& get_cmd_arguments ();
+	const std::vector<std::string>& get_cmd_arguments ();
 	
-	void   set_filename (const string &filename);
+	void   set_filename (const std::string &filename);
 
     private:
 	int    session_save_cb (int                phase,
