@@ -1,4 +1,4 @@
-//$Id: storage-node.h,v 1.4 2001/09/17 19:09:26 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.h,v 1.5 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,13 +32,13 @@ namespace Guikachu
 	StorageNode ();
 	StorageNode (xmlNodePtr root);
 
-	inline string name () const { return (char*)(node_ptr->name); };
-
-	inline xmlNodePtr c_node () const { return node_ptr; };
+	inline std::string name   () const { return (char*)(node_ptr->name); };
+	inline xmlNodePtr  c_node () const { return node_ptr; };
 	
 	/* Tree management */
-	StorageNode add_node (const string &name,
-			      const string &content = "");
+	StorageNode add_node (const std::string &name,
+			      const std::string &content = "");
+
 	inline StorageNode children () const { return node_ptr->xmlChildrenNode; };
 	inline StorageNode next ()     const { return node_ptr->next; };
 	inline StorageNode &operator++ (int) { node_ptr = node_ptr->next; return *this; };
@@ -46,26 +46,22 @@ namespace Guikachu
 	inline operator bool () { return node_ptr != 0; }
 	
 	/* Content management */
-	void   set_content (const string& content);
-	string get_content () const;
+	void        set_content (const std::string& content);
+	std::string get_content () const;
 
 	/* Property manipulation */
-	template<class T> void set_prop (const string      &prop_name,
+	template<class T> void set_prop (const std::string &prop_name,
 					 const Property<T> &value);
-	void set_prop (const string &prop_name,
-		       const string &value);
-	void set_prop (const string &prop_name,
-		       int           value);
-	void set_prop (const string &prop_name,
-		       unsigned int  value);
-	void set_prop (const string &prop_name,
-		       char          value);
+	void set_prop (const std::string &prop_name, const std::string &value);
+	void set_prop (const std::string &prop_name, int value);
+	void set_prop (const std::string &prop_name, unsigned int value);
+	void set_prop (const std::string &prop_name, char value);
 
-	template<class T> T get_prop (const string &prop_name) const;
+	template<class T> T get_prop (const std::string &prop_name) const;
     };
 
     template<class T>
-    void StorageNode::set_prop (const string      &prop_name,
+    void StorageNode::set_prop (const std::string &prop_name,
 				const Property<T> &value)
     {
 	set_prop (prop_name, value ());
