@@ -1,4 +1,4 @@
-//$Id: storage.cc,v 1.1 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: storage.cc,v 1.2 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,7 +34,7 @@ Storage::~Storage ()
 	xmlFreeDoc (doc);
 }
 
-bool Storage::load (const string &filename)
+bool Storage::load (const std::string &filename)
 {
     if (doc)
 	xmlFreeDoc (doc);
@@ -44,7 +44,7 @@ bool Storage::load (const string &filename)
     return (doc != 0);
 }
 
-void Storage::save (const string &filename) const
+void Storage::save (const std::string &filename) const
 {
     g_return_if_fail (doc != 0);
     if (!doc)
@@ -67,7 +67,7 @@ void Storage::set_root (StorageNode &node)
     xmlDocSetRootElement (doc, node.c_node ());
 }
 
-StorageNode Storage::create_root (const string &name)
+StorageNode Storage::create_root (const std::string &name)
 {
     g_return_val_if_fail (doc != 0, 0);
     
