@@ -1,4 +1,4 @@
-//$Id: storage.h,v 1.1 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: storage.h,v 1.2 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,12 +31,12 @@ namespace Guikachu
 	Storage ();
 	~Storage ();
 
-	bool load (const string &filename);
-	void save (const string &filename) const;
+	bool load (const std::string &filename);
+	void save (const std::string &filename) const;
 	
-	StorageNode get_root     () const;
+	StorageNode get_root    () const;
 	void        set_root    (StorageNode &root);
-	StorageNode create_root (const string &name);
+	StorageNode create_root (const std::string &name);
     };
 };
 
