@@ -1,4 +1,4 @@
-//$Id: string-win.cc,v 1.10 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
+//$Id: string-win.cc,v 1.11 2001/11/06 17:04:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
@@ -40,7 +40,7 @@ GUI::StringWindow::StringWindow (Guikachu::Resources::String *res_):
     window->delete_event.connect (slot (this, &StringWindow::delete_event_impl));
     window->set_policy (false, true, false);
     
-#ifdef USE_WM_ICONS
+#ifdef GUIKACHU_USE_WM_ICONS
     gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
 #endif    
 
