@@ -1,4 +1,4 @@
-//$Id: string-win.h,v 1.5 2001/08/19 13:18:44 cactus Exp $ -*- c++ -*-
+//$Id: string-win.h,v 1.6 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_STRING_WIN_H
-#define GUIKATCHU_STRING_WIN_H
+#ifndef GUIKACHU_STRING_WIN_H
+#define GUIKACHU_STRING_WIN_H
 
 namespace Guikachu
 {
@@ -52,4 +52,4 @@ namespace Guikachu
     };
 };
 
-#endif /* !GUIKATCHU_STRING_WIN_H */
+#endif /* !GUIKACHU_STRING_WIN_H */
