@@ -1,4 +1,4 @@
-//$Id: top-treeitem.cc,v 1.2 2001/03/31 21:16:17 cactus Exp $ -*- c++ -*-
+//$Id: top-treeitem.cc,v 1.3 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,8 +47,8 @@ void GUI::TopTreeItem::application_changed_cb ()
 {
     remove ();
 
-    if (res->get_iconname () != "")
-	add_label (res->get_iconname ());
+    if (res->iconname != "")
+	add_label (res->iconname);
     else
 	add_label (_("Application"));
 }
