@@ -1,4 +1,4 @@
-//$Id: treeitem.cc,v 1.5 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: treeitem.cc,v 1.6 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -37,7 +37,7 @@ GUI::TreeItem::TreeItem (Resources::Resource *res_):
     
     res->changed.connect (slot (this, &GUI::TreeItem::resource_changed_cb));
     
-    list <UI::Info> popup_menu_list;
+    std::list <UI::Info> popup_menu_list;
     popup_menu_list.push_back (
 	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
 		  _("Remove"),
