@@ -1,4 +1,4 @@
-//$Id: treeitem.h,v 1.1 2001/02/18 14:29:22 cactus Exp $ -*- c++ -*-
+//$Id: treeitem.h,v 1.2 2001/03/06 18:25:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,9 +44,10 @@ namespace Guikachu
 	    TreeItem (Resources::Resource *res_);
 	    
 	private:
-	    int clicked_cb (GdkEventButton *e);
+	    int button_press_cb (GdkEventButton *e);
+	    int key_press_cb (GdkEventKey *e);
 	    void resource_changed_cb ();
-	    void menu_remove_cb ();
+	    void remove_cb();
 	};
     }
 }
