@@ -1,4 +1,4 @@
-//$Id: auto-toggle.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: auto-toggle.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include <gtk--/checkbutton.h>
 #include <gtk--/box.h>
+#include "property.h"
 
 namespace Guikachu
 {
@@ -28,17 +29,14 @@ namespace Guikachu
     {
 	class AutoToggle: public Gtk::HBox
 	{
-	    Gtk::CheckButton togglebutton;
-	    Gtk::Widget&      widget;
-	    
-	    SigC::Slot0<bool> get_val;
-	    SigC::Slot1<void, const bool&> set_val;
+	    Gtk::CheckButton  togglebutton;
+	    Gtk::Widget      &widget;
+
+	    Property<bool>   &property;
 	    
 	public:
-	    AutoToggle (Gtk::Widget& widget,
-			SigC::Slot0<bool> get_slot,
-			SigC::Slot1<void, const bool&> set_slot,
-			SigC::Signal0<void>& changed);
+	    AutoToggle (Gtk::Widget    &widget,
+			Property<bool> &property);
 	private:
 	    bool update_block;	    
 	    void update ();
