@@ -1,4 +1,4 @@
-//$Id: entry.h,v 1.3 2001/10/28 14:08:48 cactus Exp $ -*- c++ -*-
+//$Id: entry.h,v 1.4 2001/11/06 12:54:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,11 +28,11 @@ namespace Guikachu
     {
 	class Entry: public Gtk::Entry
 	{
-	    Property<string> &property;
+	    Property<std::string> &property;
 
 	public:
 	    Entry (bool live_update,
-		   Property<string> &property);
+		   Property<std::string> &property);
 	private:
 	    bool update_block;	    
 	    void update ();
