@@ -1,4 +1,4 @@
-//$Id: num-entry.cc,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: num-entry.cc,v 1.3 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,11 +23,8 @@
 using namespace Guikachu::GUI;
 
 NumEntry::NumEntry (int min, int max,
-		    SigC::Slot0<int> get_slot,
-		    SigC::Slot1<void, const int&> set_slot,
-		    SigC::Signal0<void>& changed_sig):
-    get_val (get_slot),
-    set_val (set_slot),
+		    Property<int> &property_):
+    property (property_),
     update_block (false)
 {
     using namespace SigC;
@@ -39,15 +36,25 @@ NumEntry::NumEntry (int min, int max,
     set_update_policy (GTK_UPDATE_IF_VALID);
     set_digits (0);
 
-    changed_sig.connect (slot (this, &NumEntry::update));
+    property.changed.connect (slot (this, &NumEntry::update));
     update ();
 }
 
+void NumEntry::set_min (int min)
+{
+    get_adjustment ()->set_lower (min);
+}
+
+void NumEntry::set_max (int max)
+{
+    get_adjustment ()->set_upper (max);
+}
+
 void NumEntry::update ()
 {
     update_block = true;
 
-    set_value (get_val ());
+    set_value (property);
     
     update_block = false;
 }
@@ -55,5 +62,5 @@ void NumEntry::update ()
 void NumEntry::changed_cb ()
 {
     if (!update_block)
-	set_val (get_value_as_int ());
+	property = get_value_as_int ();
 }
