@@ -1,4 +1,4 @@
-//$Id: num-entry.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: num-entry.h,v 1.3 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,7 @@
 #define GUIKACHU_WIDGETS_NUM_ENTRY_H
 
 #include <gtk--/spinbutton.h>
+#include "property.h"
 
 namespace Guikachu
 {
@@ -27,13 +28,13 @@ namespace Guikachu
     {
 	class NumEntry: public Gtk::SpinButton
 	{
-	    SigC::Slot0<int> get_val;
-	    SigC::Slot1<void, const int&> set_val;
+	    Property<int> &property;
 	public:
 	    NumEntry (int min, int max,
-		      SigC::Slot0<int> get_slot,
-		      SigC::Slot1<void, const int&> set_slot,
-		      SigC::Signal0<void>& changed);
+		      Property<int> &property);
+	    void set_min (int min);
+	    void set_max (int max);
+	    
 	private:
 	    bool update_block;
 	    void update ();
