@@ -1,4 +1,4 @@
-//$Id: propertytable.cc,v 1.12 2001/11/10 15:13:00 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.cc,v 1.13 2001/11/12 17:01:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,6 +31,7 @@ using namespace Guikachu::GUI;
 
 PropertyTable::PropertyTable ():
     accel_group (Gtk::AccelGroup::create ()),
+    accel_parent (0),
     curr_row (0)
 {
     set_border_width (5);
@@ -171,8 +172,11 @@ void PropertyTable::parent_changed_cb (Gtk::Widget *old_parent)
 
 	Gtk::Window *old_window = dynamic_cast<Gtk::Window*> (old_toplevel);
 	
-	if (old_window)
+	if (old_window && old_window == accel_parent)
+	{
 	    old_window->remove_accel_group (*accel_group);
+	    accel_parent = 0;
+	}
     }
 }
 
@@ -181,5 +185,13 @@ void PropertyTable::map_cb ()
     GtkWidget *new_parent = gtk_widget_get_toplevel (GTK_WIDGET (gtkobj ()));
 
     if (new_parent && GTK_IS_WINDOW (new_parent))
-	Gtk::wrap (GTK_WINDOW (new_parent))->add_accel_group (*accel_group);
+    {
+	Gtk::Window *new_parent_win = Gtk::wrap (GTK_WINDOW (new_parent));
+
+	if (new_parent_win != accel_parent)
+	{
+	    accel_parent = new_parent_win;
+	    accel_parent->add_accel_group (*accel_group);
+	}
+    }
 }
