@@ -1,4 +1,4 @@
-//$Id: resource-combo.cc,v 1.3 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.cc,v 1.4 2001/11/06 12:54:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,6 +25,8 @@
 #include "resource-manager.h"
 
 using namespace Guikachu;
+using std::string;
+using std::set;
 
 GUI::ResourceCombo::ResourceCombo (Resources::Type          type_,
 				   Properties::ResourceRef &property_):
