@@ -1,4 +1,4 @@
-//$Id: resource-combo.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.h,v 1.3 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,8 +30,8 @@ namespace Guikachu
 #include <gtk--/box.h>
 #include <gtk--/combo.h>
 #include <gtk--/button.h>
-#include "property.h"
 #include "resource.h"
+#include "resource-ref.h"
 
 namespace Guikachu
 {
@@ -43,13 +43,11 @@ namespace Guikachu
 	    Gtk::Button button_edit;
 
 	    Resources::Type type;
-	    string current;
-	    Resources::Resource *current_res;
 
-	    Property<string> &property;
+	    Properties::ResourceRef &property;
 	public:
-	    ResourceCombo (Resources::Type   type,
-			   Property<string> &property);
+	    ResourceCombo (Resources::Type          type,
+			   Properties::ResourceRef &property);
 	private:
 	    bool update_block;
 	    void update ();
