@@ -1,4 +1,4 @@
-//$Id: size-entry.cc,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: size-entry.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,9 +20,7 @@
 
 using namespace Guikachu::GUI;
 
-SizeEntry::SizeEntry (SigC::Slot0<int> get_slot,
-		      SigC::Slot1<void, const int&> set_slot,
-		      SigC::Signal0<void>& changed):
-    NumEntry (1, 160, get_slot, set_slot, changed)
+SizeEntry::SizeEntry (Property<int> &property):
+    NumEntry (1, 160, property)
 {
 }
