@@ -1,4 +1,4 @@
-//$Id: string-list.cc,v 1.7 2001/11/03 20:18:27 cactus Exp $ -*- c++ -*-
+//$Id: string-list.cc,v 1.9 2001/11/10 14:11:13 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,6 +26,8 @@
 #include <gnome--/stock.h>
 
 using namespace Guikachu::GUI;
+using std::string;
+using std::vector;
 
 StringList::StringList (Property<value_t> &property_):
     Gtk::HBox (false, 5),
@@ -160,14 +162,6 @@ void StringList::selection_cb ()
 	for (Gtk::Box::BoxList::iterator i = begin; i != end; i++)
 	    (*i)->get_widget ()->set_sensitive (true);
 
-	/*
-	cerr << index << endl;
-	const value_t &vec = property;
-	if (index > vec.size ())
-	    return;
-	*/
-	    
-//	const string current_text = vec[index];
 	entry.set_text (property ()[index]);
     }
 }
