@@ -1,4 +1,4 @@
-//$Id: string-list.h,v 1.6 2001/11/03 20:18:27 cactus Exp $ -*- c++ -*-
+//$Id: string-list.h,v 1.7 2001/11/06 12:54:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -35,7 +35,7 @@ namespace Guikachu
 	class StringList: public Gtk::HBox
 	{
 	protected:
-	    typedef vector<string> value_t;
+	    typedef std::vector<std::string> value_t;
 	    Property<value_t> &property;
 
 	    Gtk::List    list_widget;
@@ -54,7 +54,7 @@ namespace Guikachu
 	    bool update_block;
 	    void add_button (Gtk::Widget &widget);
 	    void clear_list ();
-	    void add_to_list (int index, const string &label);
+	    void add_to_list (int index, const std::string &label);
 
 	    SigC::Signal1<void, unsigned int> item_added;
 	    SigC::Signal1<void, unsigned int> item_removed;
