@@ -1,4 +1,4 @@
-//$Id: text.h,v 1.1 2001/08/19 13:18:45 cactus Exp $ -*- c++ -*-
+//$Id: text.h,v 1.2 2001/11/06 12:54:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,10 +28,10 @@ namespace Guikachu
     {
 	class TextArea: public Gtk::Text
 	{
-	    Property<string> &text;
+	    Property<std::string> &text;
 
 	public:
-	    TextArea (Property<string> &text);
+	    TextArea (Property<std::string> &text);
 	private:
 	    bool update_block;
 	    void update ();
