@@ -1,4 +1,4 @@
-//$Id: togglebutton.cc,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: togglebutton.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,19 +23,15 @@
 
 using namespace Guikachu::GUI;
 
-ToggleButton::ToggleButton (SigC::Slot0<bool> get_slot,
-			    SigC::Slot1<void, const bool&> set_slot,
-			    SigC::Signal0<void>& changed):
-    Gtk::ToggleButton (_("No"), 0.5, 0.5),
-    get_val (get_slot),
-    set_val (set_slot),
+ToggleButton::ToggleButton (Property<bool> &property_):
+    property (property_),
     update_block (false)
 {
     using namespace SigC;
     
     clicked.connect (slot (this, &ToggleButton::clicked_cb));
     
-    changed.connect (slot (this, &ToggleButton::update));
+    property.changed.connect (slot (this, &ToggleButton::update));
     update ();
 }
 
@@ -43,10 +39,10 @@ void ToggleButton::update ()
 {
     update_block = true;
     
-    set_active (get_val ());
+    set_active (property);
     
     remove ();
-    if (get_active ())
+    if (property)
 	add_label (_("Yes"), 0.5, 0.5);
     else
 	add_label (_("No"),  0.5, 0.5);
@@ -57,5 +53,5 @@ void ToggleButton::update ()
 void ToggleButton::clicked_cb ()
 {
     if (!update_block)
-	set_val (get_active ());
+	property = get_active ();
 }
