@@ -1,4 +1,4 @@
-//$Id: togglebutton.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: togglebutton.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,7 @@
 #define GUIKACHU_TOGGLE_BUTTON_H
 
 #include <gtk--/togglebutton.h>
+#include "property.h"
 
 namespace Guikachu
 {
@@ -27,12 +28,9 @@ namespace Guikachu
     {
 	class ToggleButton: public Gtk::ToggleButton
 	{
-	    SigC::Slot0<bool> get_val;
-	    SigC::Slot1<void, const bool&> set_val;
+	    Property<bool> &property;
 	public:
-	    ToggleButton (SigC::Slot0<bool> get_slot,
-			  SigC::Slot1<void, const bool&> set_slot,
-			  SigC::Signal0<void>& changed);
+	    ToggleButton (Property<bool> &property);
 	private:
 	    bool update_block;
 	    void update ();
