@@ -1,4 +1,4 @@
-//$Id: widget-combo.cc,v 1.6 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
+//$Id: widget-combo.cc,v 1.7 2001/11/06 12:54:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,9 +21,10 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include <vector>
-
 using namespace Guikachu;
+using std::string;
+using std::set;
+using std::vector;
 
 GUI::WidgetCombo::WidgetCombo (Resources::Form       *form_,
 			       Widgets::Type          type_,
