@@ -1,4 +1,4 @@
-//$Id: widget-combo.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: widget-combo.h,v 1.3 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,9 +30,8 @@ namespace Guikachu
 #include <gtk--/box.h>
 #include <gtk--/combo.h>
 #include <gtk--/button.h>
-#include "property.h"
 #include "form-editor/widget.h"
-#include "form-res.h"
+#include "form-editor/widget-ref.h"
 
 namespace Guikachu
 {
@@ -45,14 +44,12 @@ namespace Guikachu
 	    Gtk::Button button_edit;
 	    
 	    Widgets::Type type;
-	    string current;
-	    Widgets::Widget *current_widget;
 
-	    Property<string> &property;
+	    Properties::WidgetRef &property;
 	public:
-	    WidgetCombo (Resources::Form  *form,
-			 Widgets::Type     type,
-			 Property<string> &property);
+	    WidgetCombo (Resources::Form       *form,
+			 Widgets::Type          type,
+			 Properties::WidgetRef &property);
 	private:
 	    bool update_block;
 	    void update ();
